import React from 'react';

import { AuthenticationState } from '@bsc/redux-authentication';

import AppHeader from './components/commons/header';
import Routes from './components/pages/routes';
import Notifier from './components/commons/notifier';
import { safeAuthenticationManager } from './helpers/authentication';

interface AppProps {
  authentification: AuthenticationState;
  lang: string;
  selectLang: any;
  getIntlFromBack: any;
}

interface AppState {
  authentificatedBySafe: boolean | null;
  authentificatedByApp: boolean | null;
}

class AppRoot extends React.Component<AppProps, AppState> {
  state = {
    authentificatedBySafe: null,
    authentificatedByApp: null,
  };

  async componentDidMount() {
    try {
      await safeAuthenticationManager.login();
      const { authentification, getIntlFromBack } = this.props;
      await getIntlFromBack();
      const currentAuthenticatedByApp = authentification.user ? authentification.user.roles.length > 0 : false;

      this.setState(prevState => ({
        // We check if a token exist, if the prevState is different from that boolean we set it
        authentificatedBySafe:
          prevState.authentificatedBySafe !== !!authentification.accessToken
            ? !!authentification.accessToken
            : prevState.authentificatedBySafe,
        // We check if authenticatedByApp (if we have roles) is different
        // from the previous state and set it if need be
        // Later we could pass an array of roles and manages routes by roles
        authentificatedByApp:
          authentification.user && prevState.authentificatedByApp !== currentAuthenticatedByApp
            ? currentAuthenticatedByApp
            : prevState.authentificatedByApp,
      }));
    } catch (error) {
      window.location.reload(true);
    }
  }
  render() {
    return (
      <>
        <AppHeader />
        <Notifier />
        <Routes
          authentificatedByApp={this.state.authentificatedByApp}
          authentificatedBySafe={this.state.authentificatedBySafe}
        />
      </>
    );
  }
}

export default AppRoot;
