import React, { FunctionComponent, useState, useEffect } from 'react';
import Card from '@material-ui/core/Card';
import Grid from '@material-ui/core/Grid';
import CardContent from '@material-ui/core/CardContent';
import CardActions from '@material-ui/core/CardActions';
import Typography from '@material-ui/core/Typography';
import CardHeader from '@material-ui/core/CardHeader';
import Button from '@material-ui/core/Button';

import Props from './SelectSupplierCard.interface';

export const SelectSupplierCard: FunctionComponent<Props> = props => {
  const { classes, supplier, cardLabels, selectSupplierEffect, unselectSupplierEffect, isCardSelected } = props;
  const supplierReferenced = supplier.approvedByRESG ? 'Oui' : 'Non';
  let [cardSelected, selectCard] = useState(isCardSelected);
  let [buttonLabel, setButtonLabel] = useState('');
  let [cardBorder, setCardBorder] = useState(classes.unselectedCardBorder);

  useEffect(() => {
    selectCard(isCardSelected);
  }, [isCardSelected]);

  useEffect(() => {
    setCardBorder(cardSelected ? classes.selectedCardBorder : classes.unselectedCardBorder);
    setButtonLabel(cardSelected ? cardLabels.removeButtonLabel : cardLabels.addButtonLabel);
  });

  const getSupplierReferencedDotStyle = () => {
    const supplierReferencedDotColor = supplier.approvedByRESG ? classes.greenBackgroung : classes.redBackgroung;
    return `${classes.dot} ${supplierReferencedDotColor}`;
  };

  const getextStatusDotStyle = () => {
    let extStatusDotColor;
    switch (supplier.extStatus.toLowerCase()) {
      case 'high':
        extStatusDotColor = classes.redBackgroung;
        break;
      case 'low':
        extStatusDotColor = classes.greenBackgroung;
        break;
      case 'medium_high':
        extStatusDotColor = classes.orangeBackgroung;
        break;
      case 'medium_low':
        extStatusDotColor = classes.greenBackgroung;
        break;
      default:
        break;
    }
    return `${classes.dot} ${extStatusDotColor}`;
  };

  const handleButtonClick = () => {
    selectCard(!cardSelected);
    setButtonLabel(cardSelected ? cardLabels.removeButtonLabel : cardLabels.addButtonLabel);
    setCardBorder(cardSelected ? classes.selectedCardBorder : classes.unselectedCardBorder);
    const selectedSupplier = {
      id: supplier.id,
      name: supplier.name,
      userFirstName: supplier.userFirstName,
      userLastName: supplier.userLastName,
      userEmail: supplier.userEmail,
      approvedByRESG: supplier.approvedByRESG,
      extStatus: supplier.extStatus,
    };
    if (!cardSelected) {
      selectSupplierEffect(selectedSupplier);
    } else {
      unselectSupplierEffect(selectedSupplier);
    }
  };

  return (
    <Grid item xs={12} lg={4} md={6} xl={3}>
      <Card classes={{ root: `${classes.cardContainer} ${cardBorder}` }}>
        <CardHeader
          classes={{ root: classes.titleRoot, content: classes.titleContent, title: classes.title }}
          title={supplier.name}
        />
        <CardContent classes={{ root: classes.content }}>
          <div>
            <Typography variant="caption" classes={{ caption: classes.infoTitle }}>
              {cardLabels.riskLevelLabel}
              <span className={classes.helpDot}>i</span>
            </Typography>
            <Typography variant="body1" classes={{ body1: classes.infoValue }}>
              <span className={getextStatusDotStyle()} />
              {supplier.extStatus.charAt(0).toUpperCase() + supplier.extStatus.slice(1)}
            </Typography>
          </div>
          <div>
            <Typography variant="caption" classes={{ caption: classes.infoTitle }}>
              {cardLabels.referenceLabel}
            </Typography>
            <Typography variant="body1" classes={{ body1: classes.infoValue }}>
              <span className={getSupplierReferencedDotStyle()} />
              {supplierReferenced}
            </Typography>
          </div>
        </CardContent>
        <hr className={classes.hr} />
        <CardActions classes={{ root: classes.buttonsContainer }}>
          <Button size="small" color="primary">
            {cardLabels.detailButtonLabel}
          </Button>
          <Button size="small" color="primary" variant="outlined" onClick={handleButtonClick}>
            {buttonLabel !== '' ? buttonLabel : cardLabels.addButtonLabel}
          </Button>
        </CardActions>
      </Card>
    </Grid>
  );
};

export default SelectSupplierCard;
