import React from 'react';
import { ShallowWrapper, shallow } from 'enzyme';
import Button from '@material-ui/core/Button';
import Typography from '@material-ui/core/Typography';

import SelectSupplierCard from './SelectSupplierCard.component';
import Props from './SelectSupplierCard.interface';

describe('SelectSupplierCard', () => {
  let props: Props;
  let wrapper: ShallowWrapper;
  const testSupplier = {
    id: '1008966',
    name: 'KSI-AD',
    fiscalCode: '52851021700011',
    userId: '1103389',
    userTitle: 'Mr.',
    userFirstName: 'Pierre',
    userLastName: 'DUPONT',
    userEmail: 'p.raballand@bravosolution.fr',
    buyerManaged: false,
    address: '2 Rue Honore Manya',
    city: 'Boulogne – Billancourt',
    zipCode: '92000',
    isoCountry: 'FR',
    website: 'zefef',
    status: 'Active',
    extStatus: 'low',
    type: 'SELLER',
    approvedByRESG: false,
  };

  beforeEach(() => {
    props = {
      supplier: testSupplier,
      cardLabels: {
        riskLevelLabel: 'Niveau de risque',
        referenceLabel: 'Référence',
        detailButtonLabel: 'Detail',
        addButtonLabel: 'Ajouter',
        removeButtonLabel: 'Ajouté',
      },
      classes: {},
      selectSupplier: jest.fn(),
      unselectSupplier: jest.fn(),
      isCardSelected: false,
    };
    wrapper = shallow(<SelectSupplierCard {...props} />);
  });

  it('should generate a card with a header, content and two buttons', () => {
    expect(wrapper.find(Button)).toHaveLength(2);
    expect(
      wrapper
        .find(Button)
        .first()
        .render()
        .text(),
    ).toEqual('Detail');
    expect(
      wrapper
        .find(Button)
        .last()
        .render()
        .text(),
    ).toEqual('Ajouter');
    expect(wrapper.find('WithStyles(CardHeader)')).toHaveLength(1);
    expect(
      wrapper
        .find('WithStyles(CardHeader)')
        .first()
        .render()
        .text(),
    ).toEqual('KSI-AD');
    expect(
      wrapper
        .find(Typography)
        .at(1)
        .render()
        .text(),
    ).toEqual('Low');
  });

  it('should show different risk level depending on each card, the first carachter must be capitalized', () => {
    const customPropsHigh = {
      supplier: { ...testSupplier, extStatus: 'high' },
    };
    props = { ...props, ...customPropsHigh };
    const wrapperHigh = shallow(<SelectSupplierCard {...props} />);
    expect(
      wrapperHigh
        .find(Typography)
        .at(1)
        .render()
        .text(),
    ).not.toEqual('Highh');
    expect(
      wrapperHigh
        .find(Typography)
        .at(1)
        .render()
        .text(),
    ).not.toEqual('high');
    expect(
      wrapperHigh
        .find(Typography)
        .at(1)
        .render()
        .text(),
    ).toEqual('High');

    const customPropsMH = {
      supplier: { ...testSupplier, extStatus: 'medium_high' },
    };
    props = { ...props, ...customPropsMH };
    const wrapperMH = shallow(<SelectSupplierCard {...props} />);
    expect(
      wrapperMH
        .find(Typography)
        .at(1)
        .render()
        .text(),
    ).not.toEqual('MEDIUM_high');
    expect(
      wrapperMH
        .find(Typography)
        .at(1)
        .render()
        .text(),
    ).not.toEqual('medium_high');
    expect(
      wrapperMH
        .find(Typography)
        .at(1)
        .render()
        .text(),
    ).toEqual('Medium_high');

    const customPropsML = {
      supplier: { ...testSupplier, extStatus: 'medium_low' },
    };
    props = { ...props, ...customPropsML };
    const wrapperML = shallow(<SelectSupplierCard {...props} />);
    expect(
      wrapperML
        .find(Typography)
        .at(1)
        .render()
        .text(),
    ).not.toEqual('Medium_Low');
    expect(
      wrapperML
        .find(Typography)
        .at(1)
        .render()
        .text(),
    ).not.toEqual('medium_low');
    expect(
      wrapperML
        .find(Typography)
        .at(1)
        .render()
        .text(),
    ).toEqual('Medium_low');

    const customPropsNotEvaluated = {
      supplier: { ...testSupplier, extStatus: 'unkown' },
    };
    props = { ...props, ...customPropsNotEvaluated };
    const wrapperNE = shallow(<SelectSupplierCard {...props} />);
    expect(
      wrapperNE
        .find(Typography)
        .at(1)
        .render()
        .text(),
    ).not.toEqual('high');
    expect(
      wrapperNE
        .find(Typography)
        .at(1)
        .render()
        .text(),
    ).not.toEqual('low');
    expect(
      wrapperNE
        .find(Typography)
        .at(1)
        .render()
        .text(),
    ).toEqual('Unkown');
  });
});
