import React, { FunctionComponent } from 'react';
import Card from '@material-ui/core/Card';
import Grid from '@material-ui/core/Grid';
import CardContent from '@material-ui/core/CardContent';
import Typography from '@material-ui/core/Typography';
import CardHeader from '@material-ui/core/CardHeader';
import Icon from '@material-ui/core/Icon';
import IconButton from '@material-ui/core/IconButton';

import Props from './SelectedSupplierCard.interface';

export const SelectedSupplierCard: FunctionComponent<Props> = props => {
  const { classes, supplier, cardLabels, unselectSupplierEffect } = props;

  const handleButtonClick = () => {
    const selectedSupplier = {
      id: supplier.id,
      name: supplier.name,
      userFirstName: supplier.userFirstName,
      userLastName: supplier.userLastName,
      userEmail: supplier.userEmail,
      approvedByRESG: supplier.approvedByRESG,
      extStatus: supplier.extStatus,
    };
    unselectSupplierEffect(selectedSupplier);
  };

  const getSupplierReferencedDotStyle = () => {
    const supplierReferencedDotColor = supplier.approvedByRESG ? classes.greenBackgroung : classes.redBackgroung;
    return `${classes.dot} ${supplierReferencedDotColor}`;
  };

  const getSupplierRiskLevelDotStyle = () => {
    let supplierRiskLevelDotColor;
    switch (supplier.extStatus.toLowerCase()) {
      case 'high':
        supplierRiskLevelDotColor = classes.redBackgroung;
        break;
      case 'low':
        supplierRiskLevelDotColor = classes.greenBackgroung;
        break;
      case 'medium_high':
        supplierRiskLevelDotColor = classes.orangeBackgroung;
        break;
      case 'medium_low':
        supplierRiskLevelDotColor = classes.greenBackgroung;
        break;
      default:
        break;
    }
    return `${classes.dot} ${supplierRiskLevelDotColor}`;
  };

  return (
    <Grid item xs={12}>
      <Card classes={{ root: classes.cardContainer }}>
        <div className={classes.headerContainer}>
          <CardHeader classes={{ root: classes.titleRoot, title: classes.title }} title={supplier.name} />
          <IconButton className={classes.clearButton} aria-label="Clear" color="primary" onClick={handleButtonClick}>
            <Icon>clear</Icon>
          </IconButton>
        </div>
        <CardContent classes={{ root: classes.contentContainer }}>
          <div className={classes.contentUserInfo}>
            <b>{`${supplier.userFirstName} ${supplier.userLastName} - `}</b>
            {`${supplier.userEmail}`}
          </div>
          <div className={classes.contentSupplierInfo}>
            <div>
              <Typography variant="caption" classes={{ caption: classes.infoTitle }}>
                {cardLabels.riskLevelLabel}
                <span className={getSupplierRiskLevelDotStyle()} />
              </Typography>
            </div>
            <div>
              <Typography variant="caption" classes={{ caption: classes.infoTitle }}>
                {cardLabels.referenceLabel}
                <span className={getSupplierReferencedDotStyle()} />
              </Typography>
            </div>
          </div>
        </CardContent>
      </Card>
    </Grid>
  );
};

export default SelectedSupplierCard;
