import React from 'react';
import { ShallowWrapper, shallow } from 'enzyme';
import Button from '@material-ui/core/Button';
import IconButton from '@material-ui/core/IconButton';

import SelectedSupplierCard from './SelectedSupplierCard.component';
import Props from './SelectedSupplierCard.interface';

describe('SelectSupplierCard', () => {
  let props: Props;
  let wrapper: ShallowWrapper;
  const testSupplier = {
    id: '1008966',
    name: 'KSI-AD',
    fiscalCode: '52851021700011',
    userId: '1103389',
    userTitle: 'Mr.',
    userFirstName: 'Pierre',
    userLastName: 'DUPONT',
    userEmail: 'p.raballand@bravosolution.fr',
    buyerManaged: false,
    address: '2 Rue Honore Manya',
    city: 'Boulogne – Billancourt',
    zipCode: '92000',
    isoCountry: 'FR',
    website: 'zefef',
    status: 'Active',
    extStatus: 'low',
    type: 'SELLER',
    approvedByRESG: false,
  };

  beforeEach(() => {
    props = {
      supplier: testSupplier,
      cardLabels: {
        riskLevelLabel: 'Niveau de risque',
        referenceLabel: 'Référence',
        detailButtonLabel: 'Detail',
        addButtonLabel: 'Ajouter',
        removeButtonLabel: 'Ajouté',
      },
      classes: {},
      unselectSupplierEffect: jest.fn(),
    };
    wrapper = shallow(<SelectedSupplierCard {...props} />);
  });

  it('should generate a card with a header, content and no buttons', () => {
    expect(wrapper.find(Button)).toHaveLength(0);
    expect(wrapper.find('WithStyles(CardHeader)')).toHaveLength(1);
    expect(
      wrapper
        .find('WithStyles(CardHeader)')
        .first()
        .render()
        .text(),
    ).toEqual('KSI-AD');
  });

  it('should call unselectSupplierEffect when clear IconButton is clicked', () => {
    wrapper.find(IconButton).simulate('click');
    expect(props.unselectSupplierEffect).toHaveBeenCalledTimes(1);
  });
});
