import React, { FunctionComponent } from 'react';
import Icon from '@material-ui/core/Icon';
import { Grid, Typography, Toolbar, AppBar, Avatar, Button, Menu, MenuItem } from '@material-ui/core';

import Props from './Header.interface';
import Logout from '../navigation/logout';
import LanguageSelector from './LanguageSelector';
import logoSg from '../../../assets/images/logoSG.svg';
import AvatarIcon from '../../../assets/images/Avatar.svg';

class Header extends React.Component<Props> {
  state = {
    anchorEl: null,
  };

  render() {
    const { classes, history } = this.props;

    const backHomeHandler = () => {
      history.location.pathname !== '/' && history.push('/');
    };

    const { anchorEl } = this.state;
    const handleClick = (event: any) => {
      this.setState({ anchorEl: event.currentTarget });
    };

    const handleClose = () => {
      this.setState({ anchorEl: null });
    };

    return (
      <AppBar position="sticky" id="app-header">
        <Grid container justify="space-between" alignItems="center">
          <Grid item>
            <Toolbar>
              <Typography
                variant="h5"
                color="inherit"
                onClick={backHomeHandler}
                classes={{
                  root: classes.appLogo,
                }}
              >
                <b>Market</b>Place
              </Typography>
            </Toolbar>
          </Grid>
          <Grid item style={{ paddingRight: '1rem' }}>
            <Grid container>
              <Grid item>
                <Button onClick={handleClick}>
                  <Avatar src={AvatarIcon} alt="Avatar" />
                  <Icon>expand_more</Icon>
                </Button>
                <Menu
                  id="simple-menu"
                  anchorEl={anchorEl}
                  open={Boolean(anchorEl)}
                  onClose={handleClose}
                  disableAutoFocusItem
                  classes={{
                    paper: classes.headerMenuStyle,
                  }}
                >
                  <MenuItem
                    classes={{
                      root: classes.menuItem,
                    }}
                  >
                    <LanguageSelector />
                  </MenuItem>
                  <MenuItem
                    onClick={handleClose}
                    classes={{
                      root: classes.menuItem,
                    }}
                  >
                    <Logout />
                  </MenuItem>
                </Menu>
              </Grid>
              <Grid item style={{ display: 'flex', alignItems: 'center' }}>
                <img src={logoSg} alt="imageNotLoaded" />
              </Grid>
            </Grid>
          </Grid>
        </Grid>
      </AppBar>
    );
  }
}
export default Header;
