import React from 'react';
import { shallow } from 'enzyme';
import Input from './Input';
import { Props } from './Input.container';
import Grid from '@material-ui/core/Grid';
import RichTextEditor from './rich-text-editor';
import Autocomplete from './autocomplete';
import DateTimePicker from './date-time-picker';
import TextField from './text-field-or-area';
import SelectField from './selectfield';
import RadioButtons from './radio-button';
import WarningMessage from '../warning-message';

describe('Input', () => {
  let props: Props;
  beforeEach(() => {
    props = {
      type: 'inputTextOrTextarea',
      inputsModel: {
        test: 'Ceci est un test',
      },
      inputLabels: {
        test: 'Test label',
      },
      inputErrorTexts: {
        required: 'Test label',
      },
      inputPlaceholders: {
        test: 'Test placeholder',
      },
      errorText: 'required',
      config: {
        length: 100,
      },
      value: '',
      keyLabel: 'test',
      updateField: jest.fn(),
      toggleTouched: jest.fn(),
      handleSearch: jest.fn(),
      resetSuggestions: jest.fn(),
      valid: false,
      touched: true,
      classes: {
        input: '',
      },
    };
  });
  it('should display a custom TextField with warningMessage', () => {
    props.config.length = 50;
    props.value = null;
    props.placeholder = 'test';
    props.helperText = {
      content: 'test',
    };
    const wrapper = shallow(<Input {...props} />);
    expect(wrapper.find(Grid)).toHaveLength(2);
    expect(wrapper.find(TextField)).toHaveLength(1);
    expect(wrapper.find(WarningMessage)).toHaveLength(1);
  });
  it('should display a custom SelectField', () => {
    props.type = 'selectfield';
    const wrapper = shallow(<Input {...props} />);
    expect(wrapper.find(Grid)).toHaveLength(1);
    expect(wrapper.find(SelectField)).toHaveLength(1);
  });
  it('should display a custom RichTextEidtor', () => {
    props.type = 'richTextEditor';
    const wrapper = shallow(<Input {...props} />);
    expect(wrapper.find(Grid)).toHaveLength(1);
    expect(wrapper.find(RichTextEditor)).toHaveLength(1);
  });
  it('should display a custom Autocomplete', () => {
    props.type = 'autocomplete';
    const wrapper = shallow(<Input {...props} />);
    expect(wrapper.find(Grid)).toHaveLength(1);
    expect(wrapper.find(Autocomplete)).toHaveLength(1);
  });
  it('should display a custom Autocomplete', () => {
    props.type = 'datePicker';
    const wrapper = shallow(<Input {...props} />);
    expect(wrapper.find(Grid)).toHaveLength(1);
    expect(wrapper.find(DateTimePicker)).toHaveLength(1);
  });
  it('should display a custom Autocomplete', () => {
    props.type = 'radioButtons';
    const wrapper = shallow(<Input {...props} />);
    expect(wrapper.find(Grid)).toHaveLength(1);
    expect(wrapper.find(RadioButtons)).toHaveLength(1);
  });
  it('should display an error if not supportent', () => {
    props.type = 'Not supported';
    const wrapper = shallow(<Input {...props} />);
    expect(wrapper.find(Grid)).toHaveLength(1);
    expect(wrapper.find('div')).toHaveLength(1);
  });
});
