import React from 'react';
import { shallow, mount } from 'enzyme';
import Autocomplete from './Autocomplete';
import Downshift from 'downshift';
import TextFieldOrArea from '../text-field-or-area';
import Suggestion from './suggestion';
import { Props } from './Autocomplete.interface';

describe('Autocomplete', () => {
  let props: Props;
  beforeEach(() => {
    props = {
      suggestions: [{ backId: 'test', value: 'Test value' }],
      classes: {
        container: 'container',
        paper: 'paper',
        showIcon: 'showIcon',
      },
      apiToCall: 'People',
      handleToggle: jest.fn(),
      handleChange: jest.fn(),
      handleSearch: jest.fn(),
      handleValue: jest.fn(),
      resetSuggestions: jest.fn(),
      valid: false,
      readOnly: false,
      disabled: false,
      touched: false,
      errorText: '',
      value: '',
    };
  });
  it('should generate an autocomplete field', () => {
    const wrapper = shallow(<Autocomplete {...props} />);
    expect(wrapper.find(Downshift)).toHaveLength(1);
  });
  it('should generate an usable autocomplete field', () => {
    props.value = '3000329357';
    const wrapper = mount(<Autocomplete {...props} />);
    expect(wrapper.find(TextFieldOrArea)).toHaveLength(1);
    wrapper.find('input').simulate('change', { target: { value: 'X123456' } });
    expect(wrapper.find(Suggestion)).toHaveLength(1);
    wrapper.find(Suggestion).simulate('click');
    expect(props.handleChange).toHaveBeenCalledWith('test');
  });
});
