import React, { FunctionComponent, useState } from 'react';
import Grid from '@material-ui/core/Grid';
import ExpansionPanel from '@material-ui/core/ExpansionPanel';
import ExpansionPanelSummary from '@material-ui/core/ExpansionPanelSummary';
import ExpansionPanelDetails from '@material-ui/core/ExpansionPanelDetails';
import Typography from '@material-ui/core/Typography';
import ExpandMoreIcon from '@material-ui/icons/ExpandMore';
// @ts-ignore-start
import { ProgressBar } from 'react-step-progress-bar';
// @ts-ignore-end
import 'react-step-progress-bar/styles.css';
import Input from '@material-ui/core/Input';
import Button from '@material-ui/core/Button';
import Table from '@material-ui/core/Table';
import TableBody from '@material-ui/core/TableBody';
import TableCell from '@material-ui/core/TableCell';
import TableHead from '@material-ui/core/TableHead';
import TableRow from '@material-ui/core/TableRow';
import IconButton from '@material-ui/core/IconButton';
import DeleteIcon from '@material-ui/icons/Delete';
import AddIcon from '@material-ui/icons/Add';

import Props from './Criteria.interface';
import WarningMessage from '../../warning-message';
import AddCriteria from './add-criteria';

export const Criteria: FunctionComponent<Props> = props => {
  const {
    classes,
    criteria,
    titles,
    helperMessage,
    handleChangeSubCriteria,
    handleChangeCriteria,
    handleRemoveSubCriteria,
    handleAddSubCriteria,
    errorText,
    tableMessages,
  } = props;
  const [showAddCriteria, setShowAddCriteria]: any = useState(false);
  const { code, value, criteriaSelectionDetails } = criteria;
  const hasDetails = criteria.canHaveDetails;
  let sum = 0;

  return (
    <ExpansionPanel className={classes.container} defaultExpanded={hasDetails}>
      <ExpansionPanelSummary
        expandIcon={hasDetails && <ExpandMoreIcon />}
        classes={{ content: classes.criteriaHeader, expandIcon: classes.expandIcon, expanded: classes.expanded }}
      >
        <Grid item xs={6} className={classes.title}>
          <Typography variant="subtitle2">
            <b>{`${titles[code].toUpperCase()}`}</b>
          </Typography>
          {code === 'BUS' && (
            <Typography variant="caption" className={classes.helperMessage}>
              {helperMessage}
            </Typography>
          )}
        </Grid>
        <Grid item xs={4}>
          <ProgressBar percent={value} />
        </Grid>
        <Grid item xs={2}>
          <Input
            value={value}
            classes={{
              root: classes.inputRoot,
              input: classes.input,
            }}
            onChange={(event: any) => {
              handleChangeCriteria(+event.target.value, criteria);
              // setTimeout(() => {
              // }, 500);
            }}
          />
          <span>%</span>
        </Grid>
      </ExpansionPanelSummary>
      {hasDetails && (
        <ExpansionPanelDetails className={classes.panelDetailsContainer}>
          <Table className={classes.table}>
            <TableHead className={classes.tableHeader}>
              <TableRow>
                <TableCell>{`${titles[code].toUpperCase()}`}</TableCell>
                <TableCell align="right">{tableMessages.percentage}</TableCell>
                <TableCell align="right">{tableMessages.actions}</TableCell>
              </TableRow>
            </TableHead>
            <TableBody>
              {criteriaSelectionDetails.map((subCriteria: any) => {
                sum += subCriteria.value;
                return (
                  <TableRow key={subCriteria.orderNum}>
                    <TableCell component="th" scope="row">
                      {titles[subCriteria.code]}
                    </TableCell>
                    <TableCell align="right">
                      <Input
                        value={subCriteria.value}
                        classes={{
                          root: classes.inputSubCriteriaRoot,
                          input: classes.input,
                        }}
                        onChange={(event: any) => {
                          handleChangeSubCriteria(+event.target.value, subCriteria);
                          // setTimeout(() => {
                          // }, 500);
                        }}
                      />
                      <span>%</span>
                    </TableCell>
                    <TableCell align="right">
                      <IconButton aria-label="Delete" onClick={() => handleRemoveSubCriteria(subCriteria, criteria)}>
                        <DeleteIcon fontSize="small" />
                      </IconButton>
                    </TableCell>
                  </TableRow>
                );
              })}
              <TableRow>
                <TableCell component="th" scope="row">
                  <Typography className={sum < 100 || sum > 100 ? classes.redTextColor : ''}>
                    {tableMessages.total}
                  </Typography>
                </TableCell>
                <TableCell align="right">
                  <Typography
                    className={`${classes.totalPercentage} ${sum < 100 || sum > 100 ? classes.redTextColor : ''}`}
                  >
                    {`${sum}%`}
                  </Typography>
                </TableCell>
                <TableCell align="right" />
              </TableRow>
            </TableBody>
          </Table>
          {errorText && <WarningMessage helperText={{ content: errorText, type: 'error', icon: 'warning' }} />}
          <Button variant="contained" className={classes.addCriteriaButton} onClick={() => setShowAddCriteria(true)}>
            <AddIcon />
            {tableMessages.addCriteriaButton}
          </Button>
          {showAddCriteria && (
            <Grid container>
              <AddCriteria
                handleCancel={setShowAddCriteria}
                handleAddSubCriteria={handleAddSubCriteria}
                criteria={criteria}
              />
            </Grid>
          )}
        </ExpansionPanelDetails>
      )}
    </ExpansionPanel>
  );
};

export default Criteria;
