import React, { FunctionComponent, useState } from 'react';
import TextField from '../../text-field-or-area';
import Button from '@material-ui/core/Button';
import Grid from '@material-ui/core/Grid';
import Input from '@material-ui/core/Input';

import Props from './AddCriteria.interface';

const addCriteria: FunctionComponent<Props> = props => {
  const { classes, handleCancel, criteria, handleAddSubCriteria, messages } = props;
  const [label, setLabel] = useState('');
  const [value, setValue] = useState(0);
  const subCriteria = {
    code: `CUSTOM-CRITERIA-${Math.floor(Math.random() * Math.floor(1000))}`,
    label,
    value,
  };

  return (
    <Grid item xs={12}>
      <Grid container className={classes.container}>
        <Grid item xs={9}>
          <div className={classes.textContainer}>
            <TextField
              keyLabel={messages.addCriteriaLabel}
              value={label}
              handleChange={setLabel}
              handleToggle={() => {}}
              validation={{}}
              muiPropsCustomConf={{
                variant: 'outlined',
                required: true,
              }}
            />
          </div>
        </Grid>
        <Grid item xs={1}>
          <Input
            onChange={(event: any) => setValue(+event.target.value)}
            classes={{
              root: classes.inputRoot,
              input: classes.input,
            }}
          />
          <span>%</span>
        </Grid>
        <Grid item xs={1}>
          <Button
            variant="contained"
            color="primary"
            className={classes.validationButton}
            onClick={() => {
              handleAddSubCriteria(subCriteria, criteria);
              handleCancel(false);
            }}
          >
            {messages.validateAddCriteriaButton}
          </Button>
        </Grid>
        <Grid item xs={1}>
          <Button variant="contained" onClick={() => handleCancel(false)} disabled={label.length <= 0}>
            {messages.cancelAddCriteriaButton}
          </Button>
        </Grid>
      </Grid>
    </Grid>
  );
};

export default addCriteria;
