import React from 'react';
import { mount } from 'enzyme';
import DownloadSingleFile from './DownloadSingleFile';
import Provider from './../../../../providers/store.provider';
import SvgIcon from '@material-ui/core/SvgIcon';
import Fab from '@material-ui/core/Fab';
import { Grid } from '@material-ui/core';
import WarningMessage from '../../warning-message';

describe('DownloadSingleFile', () => {
  let props: any;

  beforeEach(() => {
    props = {
      prSpecificationIsValid: false,
      downloadSpecificationFileEffect: jest.fn(),
      classes: {
        downloadFileTopTextError: 'downloadFileTopTextError',
        validSectionButton: 'validSectionButton',
        svgStyle: 'svgStyle',
        downloadFileBottomText: 'downloadFileBottomText',
        invalidSectionButton: 'invalidSectionButton',
        buttonSection: 'buttonSection',
        downloadFileTopTextColorError: 'downloadFileTopTextColorError',
        downloadFileTopTextSVGError: 'downloadFileTopTextSVGError',
        downloadFileTopTextColorSuccess: 'downloadFileTopTextColorSuccess',
        downloadFileTopTextSVGSuccess: 'downloadFileTopTextSVGSuccess',
        downloadFileTopTextSuccess: 'downloadFileTopTextSuccess',
        prSpecificationInvalidInputs: ['projectName', 'contextComments'],
      },
    };
  });

  describe('Specification invalid', () => {
    it('should display a download SVG icon and an error svg icon and text at top is full screen size', () => {
      const wrapper = mount(
        <Provider>
          <DownloadSingleFile {...props} />
        </Provider>,
      );
      wrapper.setProps({});

      expect(wrapper.find(SvgIcon).length).toEqual(2);
      expect(wrapper.find(Fab).length).toEqual(1);
      expect(wrapper.find(Grid).length).toEqual(4);
    });

    it('should download file on icon click', () => {
      const wrapper = mount(
        <Provider>
          <DownloadSingleFile {...props} />
        </Provider>,
      );
      wrapper.setProps({});

      expect(wrapper.find(SvgIcon).length).toEqual(2);
      expect(wrapper.find(Fab).length).toEqual(1);
      expect(props.downloadSpecificationFileEffect).toBeCalledTimes(0);
      wrapper.find(Fab).simulate('click');
      expect(props.downloadSpecificationFileEffect).toBeCalledTimes(1);
    });
  });

  describe('Specification valid', () => {
    it('should display a download SVG icon and an error svg icon and text at top is full screen size', () => {
      props.prSpecificationIsValid = true;
      const wrapper = mount(
        <Provider>
          <DownloadSingleFile {...props} />
        </Provider>,
      );
      wrapper.setProps({});

      expect(wrapper.find(SvgIcon).length).toEqual(2);
      expect(wrapper.find(Fab).length).toEqual(1);
      expect(wrapper.find(Grid).length).toEqual(4);
    });

    it('should download file on icon click', () => {
      props.prSpecificationIsValid = true;

      const wrapper = mount(
        <Provider>
          <DownloadSingleFile {...props} />
        </Provider>,
      );
      wrapper.setProps({});

      expect(wrapper.find(SvgIcon).length).toEqual(2);
      expect(wrapper.find(Fab).length).toEqual(1);
      expect(props.downloadSpecificationFileEffect).toBeCalledTimes(0);
      wrapper.find(Fab).simulate('click');
      expect(props.downloadSpecificationFileEffect).toBeCalledTimes(1);
    });
  });
});
