import React from 'react';
import { mount } from 'enzyme';
import Dropzone from 'react-dropzone';
import FileUpload from './FileUpload';
import Provider from './../../../../providers/store.provider';
describe('FileUpload', () => {
  let props: any;

  beforeEach(() => {
    const newFiles: {
      [key: string]: any[];
    } = {
      prDragAndDropInstance1: [
        {
          name: 'file1',
        },
        {
          name: 'file2',
        },
      ],
      prDragAndDropInstance2: [
        {
          name: 'file3',
        },
        {
          name: 'file4',
        },
      ],
    };
    props = {
      fileUploadMessages: '',
      handleChange: jest.fn(),
      fileDestination: 'INTERNAL USE ONLY',
      existingFilesPropsArray: jest.fn(() => [{ name: 'file1' }]),
      newFilesPropsArray: jest.fn(keyLabel => newFiles[keyLabel]),
      createDroppedFileModelEffect: jest.fn(),
      addDroppedFileEffect: jest.fn(),
      getExistingFilesEffect: jest.fn(),
      keyLabel: 'prDragAndDropInstance1',
    };
  });

  describe('display dropZone and empty table', () => {
    it('should display one Dropzone and one FileUploadTable', () => {
      const wrapper = mount(
        <Provider>
          <FileUpload {...props} />
        </Provider>,
      );
      wrapper.setProps({});

      expect(wrapper.find(Dropzone).length).toEqual(1);
      expect(wrapper.find('input').length).toEqual(1);
      expect(wrapper.find('Grid').length).toEqual(1);
      expect(wrapper.find('Button').length).toEqual(1);
      expect(wrapper.find('AddIcon').length).toEqual(1);
      expect(wrapper.find('Connect(FileUploadTable)').length).toEqual(1);
    });
  });

  describe('display blue frame', () => {
    it('should display an uploadIcon within dropzone on file drag', () => {
      const wrapper = mount(
        <Provider>
          <FileUpload {...props} />
        </Provider>,
      );
      wrapper.setProps({});
      expect(wrapper.find('#dropBorderBox').length).toEqual(0);
      expect(wrapper.find('SvgIcon').length).toEqual(1);

      /** Simulate Drag event */
      const onDragOverFunc: any = wrapper.find(Dropzone).prop('onDragOver');
      onDragOverFunc();
      wrapper.find(Dropzone).simulate('dragover');
      /***********************/

      expect(wrapper.find('#dropBorderBox').length).toEqual(1);
      expect(wrapper.find('SvgIcon').length).toEqual(2);
    });

    it('should display a blue frame around drop-zone on file drag', () => {
      const wrapper = mount(
        <Provider>
          <FileUpload {...props} />
        </Provider>,
      );
      wrapper.setProps({});
      expect(wrapper.find('#drop-zone').length).toEqual(1);
      expect(wrapper.find('#drop-zone').prop('className')).toEqual('noDragNoBox');

      /** Simulate Drag event */
      const onDragOverFunc: any = wrapper.find(Dropzone).prop('onDragOver');
      onDragOverFunc();
      wrapper.find(Dropzone).simulate('dragover');
      /***********************/

      const lightBlue = 'rgb(165, 199, 254)';
      expect(wrapper.find('#drop-zone').prop('className')).toEqual('onDragBlueBox');
    });

    it('should hide blue frame around drop-zone when drag is stopped', () => {
      const wrapper = mount(
        <Provider>
          <FileUpload {...props} />
        </Provider>,
      );
      wrapper.setProps({});
      expect(wrapper.find('#drop-zone').length).toEqual(1);
      expect(wrapper.find('#drop-zone').prop('className')).toEqual('noDragNoBox');

      /** Simulate Drag event */
      const onDragOverFunc: any = wrapper.find(Dropzone).prop('onDragOver');
      onDragOverFunc();
      wrapper.find(Dropzone).simulate('dragover');
      /***********************/

      const lightBlue = 'rgb(165, 199, 254)';
      expect(wrapper.find('#drop-zone').prop('className')).toEqual('onDragBlueBox');

      /** Simulate Drag leave event */
      const onDragLeaveFunc: any = wrapper.find(Dropzone).prop('onDragLeave');
      onDragLeaveFunc();
      wrapper.find(Dropzone).simulate('dragleave');
      /***********************/
      expect(wrapper.find('#drop-zone').prop('className')).toEqual('noDragNoBox');
    });

    it('should hide blue frame around drop-zone when file is dropped', () => {
      const wrapper = mount(
        <Provider>
          <FileUpload {...props} />
        </Provider>,
      );
      wrapper.setProps({});
      expect(wrapper.find('#drop-zone').length).toEqual(1);
      expect(wrapper.find('#drop-zone').prop('className')).toEqual('noDragNoBox');

      /** Simulate Drag event */
      const onDragOverFunc: any = wrapper.find(Dropzone).prop('onDragOver');
      onDragOverFunc();
      wrapper.find(Dropzone).simulate('dragover');
      /***********************/
      const lightBlue = 'rgb(165, 199, 254)';
      expect(wrapper.find('#drop-zone').prop('className')).toEqual('onDragBlueBox');

      const droppedFiles: any[] = [{ id: 'file1' }, { id: 'file56' }];
      /** Simulate Drop event */
      const onDropFunc: any = wrapper.find(Dropzone).prop('onDrop');
      onDropFunc(droppedFiles);
      wrapper.find(Dropzone).simulate('drop');
      /***********************/
      expect(wrapper.find('#drop-zone').prop('className')).toEqual('noDragNoBox');
    });
  });

  describe('display files in a table', () => {
    let props2: any;
    let props3: any;

    beforeEach(() => {
      const newFiles: {
        [key: string]: any[];
      } = {
        prDragAndDropInstance1: [],
        prDragAndDropInstance2: [],
      };

      const existingFiles: {
        [key: string]: any[];
      } = {
        prDragAndDropInstance1: [
          {
            name: 'file11',
          },
          {
            name: 'file22',
          },
          {
            name: 'file44',
          },
          {
            name: 'file55',
            format: 'file55 format',
            size: '1234',
          },
        ],
        prDragAndDropInstance2: [
          {
            name: 'file33',
          },
        ],
      };

      const noExistingFiles: {
        [key: string]: any[];
      } = {
        prDragAndDropInstance1: [],
      };

      props2 = {
        fileUploadMessages: '',
        handleChange: jest.fn(),
        fileDestination: 'INTERNAL USE ONLY',
        existingFilesPropsArray: jest.fn(keyLabel => existingFiles[keyLabel]),
        newFilesPropsArray: jest.fn(keyLabel => newFiles[keyLabel]),
        createDroppedFileModelEffect: jest.fn(),
        addDroppedFileEffect: jest.fn(),
        getExistingFilesEffect: jest.fn(),
        keyLabel: 'prDragAndDropInstance1',
      };

      props3 = {
        fileUploadMessages: '',
        handleChange: jest.fn(),
        fileDestination: 'INTERNAL USE ONLY',
        existingFilesPropsArray: jest.fn(keyLabel => noExistingFiles[keyLabel]),
        newFilesPropsArray: jest.fn(keyLabel => newFiles[keyLabel]),
        createDroppedFileModelEffect: jest.fn(),
        addDroppedFileEffect: jest.fn(),
        getExistingFilesEffect: jest.fn(),
        keyLabel: 'prDragAndDropInstance1',
      };
    });

    it('should display one header, two new lines and 3 existing lines when 2 files are dropped', () => {
      const wrapper = mount(
        <Provider>
          <FileUpload {...props2} />
        </Provider>,
      );
      expect(wrapper.find('TableRow').length).toEqual(5); // 4 existing Files + 1 header

      const droppedFiles: any[] = [
        { id: 'file1', size: 100000, name: 'file1 name', type: 'image/jpeg' },
        { id: 'file56', size: 40005458, name: 'file56 name', type: 'image/jpeg' },
      ];
      /** Simulate Drop event */
      const onDropFunc: any = wrapper.find(Dropzone).prop('onDrop');
      onDropFunc(droppedFiles);
      wrapper.find(Dropzone).simulate('drop');
      /***********************/
      expect(wrapper.find('TableRow').length).toEqual(7); // 4 existing Files + 2 newFiles (dropped) + 1 header
    });

    it('should display one header and line for valid mimetype files only', () => {
      const wrapper = mount(
        <Provider>
          <FileUpload {...props2} />
        </Provider>,
      );
      expect(wrapper.find('TableRow').length).toEqual(5); // 4 existing Files + 1 header

      const droppedFiles: any[] = [
        { id: 'file1', size: 100000, name: 'file1 name', type: 'text/javascript' },
        { id: 'file56', size: 40005458, name: 'file56 name', type: 'image/jpeg' },
      ];
      /** Simulate Drop event */
      const onDropFunc: any = wrapper.find(Dropzone).prop('onDrop');
      onDropFunc(droppedFiles);
      wrapper.find(Dropzone).simulate('drop');

      /***********************/
      expect(wrapper.find('TableRow').length).toEqual(6); // 4 existing Files + 2 newFiles (dropped and only 1 valid) + 1 header
    });

    it('should display no header and no line when all dropped files are invalid', () => {
      const wrapper = mount(
        <Provider>
          <FileUpload {...props3} />
        </Provider>,
      );
      wrapper.setProps({});
      expect(wrapper.find('TableRow').length).toEqual(0);

      const droppedFiles: any[] = [
        { id: 'file1', size: 100000, name: 'file1 name', type: 'text/javascript' },
        { id: 'file56', size: 40005458, name: 'file56 name', type: 'text/javascript' },
      ];
      /** Simulate Drop event */
      const onDropFunc: any = wrapper.find(Dropzone).prop('onDrop');
      onDropFunc(droppedFiles);
      wrapper.find(Dropzone).simulate('drop');
      /***********************/
      expect(wrapper.find('TableRow').length).toEqual(0);
    });

    it('should remove one line on delete button click', () => {
      const wrapper = mount(
        <Provider>
          <FileUpload {...props3} />
        </Provider>,
      );
      expect(wrapper.find('TableRow').length).toEqual(0);

      const droppedFiles: any[] = [
        { id: 'file1', size: 100000, name: 'file1name', type: 'image/jpeg' },
        { id: 'file2', size: 100000, name: 'file2name', type: 'image/jpeg' },
        { id: 'file3', size: 100000, name: 'file3name', type: 'image/jpeg' },
        { id: 'file56', size: 40005458, name: 'file56name', type: 'image/jpeg' },
      ];
      /** Simulate Drop event */
      const onDropFunc: any = wrapper.find(Dropzone).prop('onDrop');
      onDropFunc(droppedFiles);
      wrapper.find(Dropzone).simulate('drop');
      /***********************/
      expect(wrapper.find('IconButton').length).toEqual(4);
      expect(wrapper.find('TableRow').length).toEqual(5);
      expect(wrapper.find('IconButton[id="deleteIcon-file1name"]').length).toEqual(1);
      expect(wrapper.find('IconButton[id="deleteIcon-file56name"]').length).toEqual(1);
      wrapper.find('IconButton[id="deleteIcon-file2name"]').simulate('click');
      expect(wrapper.find('IconButton').length).toEqual(3);
      expect(wrapper.find('TableRow').length).toEqual(4);
    });
  });
});
