import React, { FunctionComponent, useState, useEffect } from 'react';
import { FileUploadRootProps } from './FileUpload.interface';
import Dropzone from 'react-dropzone';
import Table from '../../../commons/table';
import Mime from 'mime-type/with-db';
import Bytes from 'bytes';
import SvgIcon from '@material-ui/core/SvgIcon';
import Button from '@material-ui/core/Button';
import { Add, Delete } from '@material-ui/icons';
import { Grid, IconButton } from '@material-ui/core';
import FileUploadTable from './file-upload-table';
import styles from './FileUpload.module.css';
import {
  addFile,
  deleteFileFunc,
  trimFileExtension,
  generateFileRows,
  acceptedFilesFunc,
} from '../../../../services/file-upload-utils';

export const fileUpload: FunctionComponent<FileUploadRootProps> = props => {
  const [newFiles, setNewFiles]: any = useState([]);
  // const [filesTableBody, setFilesTableBody]: any = useState([]);
  // We update the content of files array when we have them

  const generateFileTableRow = (
    filesParam: any,
    deleteFileParam: any,
    setFilesParam: any,
    file: any,
    fileDestination: string,
    fileIndex: number,
  ) => {
    const fileType = file.type ? file.type : file.format;
    const mimeExt = Mime.extension(`${fileType}`);

    let fileRow;
    if (typeof mimeExt!! !== 'undefined') {
      // new File
      fileRow = [
        trimFileExtension(file.name),
        mimeExt.toString().toUpperCase(),
        Bytes(file.size, { unitSeparator: ' ', decimalPlaces: 0 }),
        fileUploadMessages[fileDestination],
        <IconButton
          id={`deleteIcon-${file.name}`}
          onClick={() => deleteFileParam(fileIndex, setFilesParam, filesParam)}
        >
          <Delete />
        </IconButton>,
      ];
      return fileRow;
    } else if (typeof file.format!! !== 'undefined') {
      // existing File
      fileRow = [
        trimFileExtension(file.name),
        file.format.toUpperCase(),
        Bytes(parseInt(file.size), { unitSeparator: ' ', decimalPlaces: 0 }),
        fileUploadMessages[file.sharingStatus],
        <IconButton
          id={`deleteIcon-${file.name}`}
          onClick={() => deleteFileFromEDM(file.id, prId, keyLabel, destination, file.name)}
        >
          <Delete />
        </IconButton>,
      ];
      return fileRow;
    }
    return [];
  };

  const {
    fileUploadMessages,
    createDroppedFileModelEffect,
    addDroppedFileEffect,
    destination,
    keyLabel,
    getExistingFilesEffect,
    existingFilesPropsArray,
    newFilesPropsArray,
    deleteFileFromEDM,
    prId,
  } = props;

  useEffect(() => {
    createDroppedFileModelEffect([keyLabel]);
  }, []);

  async function getFileListFromGED() {
    await getExistingFilesEffect(keyLabel, destination);
  }

  // Load existing files on componentDidMount
  useEffect(() => {
    getFileListFromGED();
  }, []);

  useEffect(() => {
    const validFiles = acceptedFilesFunc(newFiles);

    addDroppedFileEffect(keyLabel, validFiles, 'newFiles');
  }, [newFiles, fileUploadMessages]);

  useEffect(() => {
    // Should trigger synchro from store to local state for New files array
    if (newFilesPropsArray(keyLabel).length === 0 || validFiles.length !== newFilesPropsArray(keyLabel).length) {
      setNewFiles(newFilesPropsArray(keyLabel));
    }
  }, [newFilesPropsArray]);

  const [dragOverStyle, setdragOverStyle]: any = useState({ styles: styles.noDragNoBox, isDragging: false });

  const validFiles = acceptedFilesFunc(newFiles);
  const newAndExistingFilesArray = existingFilesPropsArray(keyLabel).concat(validFiles);
  const newFilesTableBody = generateFileRows(
    newAndExistingFilesArray,
    deleteFileFunc,
    setNewFiles,
    destination,
    generateFileTableRow,
  );

  return (
    <>
      <Dropzone
        onDragLeave={() => setdragOverStyle({ styles: styles.noDragNoBox, isDragging: false })}
        onDragOver={() => setdragOverStyle({ styles: styles.onDragBlueBox, isDragging: true })}
        multiple
        onDrop={droppedFiles => {
          setdragOverStyle({ styles: styles.noDragNoBox, isDragging: false });
          addFile(droppedFiles, setNewFiles, newFiles, props.handleChange);
        }}
      >
        {({ getRootProps, getInputProps, open, acceptedFiles, rejectedFiles }) => (
          <>
            <div id={'drop-zone'} {...getRootProps()} className={dragOverStyle.styles}>
              <input {...getInputProps()} />
              <Grid container direction="row" justify="flex-start" alignItems="center">
                <Button
                  className={styles.uploadButton}
                  variant="contained"
                  color="default"
                  onClick={() => {
                    open;
                    event && event.stopPropagation();
                  }}
                >
                  <Add />
                  {fileUploadMessages['fileUploadButton']}
                </Button>
                <div>
                  <div className={styles.dragTextStyle}>{fileUploadMessages['fileDragMessage1']}</div>
                  <div className={styles.dragTextStyleBold}>{fileUploadMessages['fileDragMessage2']}</div>
                  <div className={styles.dragTextStyleNoMargin}>{fileUploadMessages['fileDragMessage3']}</div>
                </div>
              </Grid>
              {dragOverStyle.isDragging ? (
                <div id={'dropBorderBox'} className={styles.dropBorderBox}>
                  <SvgIcon viewBox={'0 0 48 48'}>
                    <path d="M38 18h-8V6H18v12h-8l14 14 14-14zM10 36v4h28v-4H10z" />
                  </SvgIcon>
                </div>
              ) : null}
            </div>
          </>
        )}
      </Dropzone>
      <FileUploadTable files={newAndExistingFilesArray} filesTableBody={newFilesTableBody} />
    </>
  );
};

export default fileUpload;
