import React from 'react';
import { reducer, initGdpr } from './Gdpr.reducer';
import { gdprModel, gdprValue } from '../../../../template/gdpr';

describe('reducer', () => {
  let initialState: any;
  beforeEach(() => {
    initialState = {
      gdprModels: [],
      gdprValues: [],
    };
  });
  it('should return initial state', () => {
    expect(reducer(initialState, {})).toEqual({
      gdprModels: [],
      gdprValues: [],
    });
  });
  it('should add a tratment', () => {
    expect(reducer(initialState, { type: 'addTreatment' })).toEqual({
      gdprModels: [{ ...gdprModel }],
      gdprValues: [{ ...gdprValue, orderNum: 0 }],
    });
  });
  it('should remove a tratment', () => {
    initialState = {
      gdprModels: [{ ...gdprModel }, { ...gdprModel }],
      gdprValues: [{ gdpr: 'test', orderNum: 0 }, { gdpr: 'Second one', orderNum: 1 }],
    };
    expect(reducer(initialState, { type: 'removeTreatment', index: 0 })).toEqual({
      gdprModels: [{ ...gdprModel }],
      gdprValues: [{ gdpr: 'Second one', orderNum: 0 }],
    });
  });
  it('should toggle an input', () => {
    (initialState.gdprModels = [
      {
        inputTest: {
          value: '',
          touched: false,
          valid: false,
          errorText: '',
          validation: {
            required: true,
          },
        },
      },
    ]),
      expect(reducer(initialState, { type: 'toggleTouched', index: 0, key: 'inputTest' })).toEqual({
        gdprModels: [
          {
            inputTest: {
              ...initialState.gdprModels[0].inputTest,
              touched: true,
              errorText: 'required',
            },
          },
        ],
        gdprValues: [],
      });
  });
  it('should update an input', () => {
    initialState = {
      gdprModels: [
        {
          inputTest: {
            value: '',
            touched: false,
            valid: false,
            errorText: null,
            validation: {
              required: true,
            },
          },
        },
      ],
      gdprValues: [{ inputTest: '' }],
    };
    expect(reducer(initialState, { type: 'updateField', newValue: 'test', index: 0, keyLabel: 'inputTest' })).toEqual({
      gdprModels: [
        {
          inputTest: {
            ...initialState.gdprModels[0].inputTest,
            value: 'test',
            touched: true,
            valid: true,
          },
        },
      ],
      gdprValues: [{ inputTest: 'test' }],
    });
  });
  it('should init the gdpr', () => {
    const action = {
      value: [
        {
          ...gdprValue,
          orderNum: 1,
        },
        {
          ...gdprValue,
          orderNum: 0,
        },
      ],
    };
    expect(initGdpr(initialState, action)).toEqual({
      gdprModels: [{ ...gdprModel }, { ...gdprModel }],
      gdprValues: [{ ...gdprValue, orderNum: 0 }, { ...gdprValue, orderNum: 1 }],
    });
  });
});
