import { gdprModel, gdprValue } from './../../../../template/gdpr';
import dotProp from 'dot-prop-immutable';
import { checkValidity } from '../../../../services/shared';

export const initialState = {
  gdprModels: [],
  gdprValues: [],
};

export const initGdpr = (state: any, action: any) => {
  const { value } = action;
  const sortedValues = value.sort((a: any, b: any) => (a.orderNum > b.orderNum ? 1 : -1));
  let updateGdprModels = sortedValues.map((treatment: any) => {
    let updateGdprModel: any = { ...gdprModel };
    Object.keys(updateGdprModel).map((key: string) => {
      const validity = checkValidity(treatment[key], updateGdprModel[key].validation);
      updateGdprModel[key] = {
        ...updateGdprModel[key],
        value: treatment[key],
        valid: validity.valid,
      };
    });
    return updateGdprModel;
  });
  return { ...state, gdprValues: action.value, gdprModels: updateGdprModels };
};

export const addTreatment = (state: any, action: any) => {
  const newGdpr = { ...gdprValue, orderNum: state.gdprValues.length };
  return { ...state, gdprModels: state.gdprModels.concat(gdprModel), gdprValues: state.gdprValues.concat(newGdpr) };
};

export const updateField = (state: any, action: any) => {
  const { index, keyLabel, newValue } = action;
  const { gdprModels, gdprValues } = state;
  const validity = checkValidity(newValue, gdprModels[index][keyLabel].validation);
  const updatedGdprModel = dotProp.merge(gdprModels[index], keyLabel, {
    value: newValue,
    touched: true,
    valid: validity.valid,
    errorText: validity.errorText,
  });
  let updatedGdprModels = gdprModels.concat();
  updatedGdprModels[index] = updatedGdprModel;
  const updatedGdprValue = { ...gdprValues[index], [keyLabel]: newValue };
  let updatedGdprValues = gdprValues.concat();
  updatedGdprValues[index] = updatedGdprValue;
  return { ...state, gdprModels: updatedGdprModels, gdprValues: updatedGdprValues };
};

export const removeTreatment = (state: any, action: any) => {
  const { index } = action;
  const { gdprModels, gdprValues } = state;
  // We remove the model at the index passed into the action
  const updatedGdprModels = gdprModels.concat().filter((_val: any, i: number) => i !== index);
  // We remove the value at the index passed into the action and update the orderNums
  const updatedGdprValues = gdprValues
    .concat()
    .filter((_val: any, i: number) => i !== index)
    .map((gdprValue: any, i: number) => ({ ...gdprValue, orderNum: i }));
  return { ...state, gdprModels: updatedGdprModels, gdprValues: updatedGdprValues };
};

export const toggleTouched = (state: any, action: any) => {
  const { gdprModels } = state;
  const { key, index } = action;
  const validity = checkValidity(gdprModels[index][key].value, gdprModels[index][key].validation);
  const updatedGdprModel = dotProp.merge(gdprModels[index], key, {
    touched: true,
    valid: validity.valid,
    errorText: validity.errorText,
  });
  let updatedGdprModels = gdprModels.concat();
  updatedGdprModels[index] = updatedGdprModel;
  return { ...state, gdprModels: updatedGdprModels };
};

export const reducer = (state: any, action: any) => {
  switch (action.type) {
    case 'initGdpr':
      return initGdpr(state, action);
    case 'addTreatment':
      return addTreatment(state, action);
    case 'removeTreatment':
      return removeTreatment(state, action);
    case 'updateField':
      return updateField(state, action);
    case 'toggleTouched':
      return toggleTouched(state, action);
    default:
      return state;
  }
};
