import React, { FunctionComponent, useReducer, useEffect, useState } from 'react';
import { Props } from './Gdpr.container';
import { Button } from '@material-ui/core';
import AddIcon from '@material-ui/icons/Add';
import { reducer, initialState } from './Gdpr.reducer';
import GdprTreatment from './gdpr-treatment';
import { isEqual } from 'lodash';

export const gdpr: FunctionComponent<Props> = props => {
  const { value } = props;
  const [state, dispatch] = useReducer(reducer, initialState);
  const [debounce, setDebounce]: any = useState(null);

  useEffect(() => {
    clearTimeout(debounce);
    setDebounce(
      setTimeout(() => {
        !isEqual(value, state.gdprValues) && props.handleChange(state.gdprValues);
      }, 500),
    );
  }, [state.gdprValues]);

  useEffect(() => {
    // If the value is different it's the one from the back so we init
    // the gdpr reducer with it
    !isEqual(value, state.gdprValues) && dispatch({ type: 'initGdpr', value });
  }, [value]);

  const toggleTouchedHandler = (key: string, index: number, type: string) => {
    const element: any = state.gdprModels[index][key];
    // If it is a blur and the element is not already touched we toggle
    if (type === 'blur' && !element.touched) {
      dispatch({ type: 'toggleTouched', index, key });
      // if it is a focus on an empty and touched element we toggle
    } else if (type === 'focus' && (element.value === '' || element.value === null) && element.touched) {
      dispatch({ type: 'toggleTouched', index, key });
    }
  };

  return (
    <>
      {state.gdprModels.map((gdprModel: any, index: number) => (
        <GdprTreatment
          key={`gdprTreatment-${index}`}
          index={index}
          updateField={(value: string, key: string) =>
            dispatch({ type: 'updateField', newValue: value, index, keyLabel: key })
          }
          removeTreatment={() => dispatch({ type: 'removeTreatment', index })}
          handleToggle={toggleTouchedHandler}
          model={gdprModel}
        />
      ))}
      <Button variant="contained" onClick={() => dispatch({ type: 'addTreatment' })}>
        <AddIcon />
        {props.gdprButtonMessage}
      </Button>
    </>
  );
};

export default gdpr;
