import React, { FunctionComponent } from 'react';
import { Grid, Paper, IconButton } from '@material-ui/core';
import Clear from '@material-ui/icons/Clear';
import TextFieldOrArea from './../../text-field-or-area/index';
import { omit } from 'lodash';
import { Props } from './GdprTreatment.container';

export const gdprTreatment: FunctionComponent<Props> = props => {
  const {
    index,
    model,
    updateField,
    inputLabels,
    classes,
    removeTreatment,
    handleToggle,
    inputErrorTexts,
    inputPlaceholders,
  } = props;
  return (
    <Paper className={classes.paper} elevation={1}>
      {index > 0 && (
        <IconButton classes={{ root: classes.button }} onClick={removeTreatment}>
          <Clear fontSize="small" />
        </IconButton>
      )}
      <Grid container>
        {Object.keys(model).map((key: string) => {
          const inputConf = model[key];
          return (
            <Grid item xs={12} md={6} key={`gdprTreatment-${props.index}-${key}`} className={classes.grid}>
              <TextFieldOrArea
                value={inputConf.value !== null ? inputConf.value : ''}
                keyLabel={inputLabels[key]}
                errorText={inputErrorTexts[inputConf.errorText]}
                placeholder={inputPlaceholders[inputConf.placeholder]}
                handleChange={(value: string) => updateField(value, key)}
                handleToggle={(type: string) => handleToggle(key, index, type)}
                {...omit(inputConf, ['value', 'errorText', 'placeholder'])}
              />
            </Grid>
          );
        })}
      </Grid>
    </Paper>
  );
};

export default gdprTreatment;
