import React from 'react';
import { shallow, mount } from 'enzyme';
import CustomRadioButton, { initValue } from './RadioButton';
import { RadioGroup, FormLabel, FormControlLabel, FormControl } from '@material-ui/core';
import { Props } from './RadioButton.container';

describe('<CustomRadioButton />', () => {
  let props: Props;
  beforeEach(() => {
    props = {
      value: 'test',
      config: {
        choices: ['test', 'other test'],
      },
      keyLabel: 'CustomRadioButton',
      handleChange: jest.fn(),
      valid: true,
      touched: true,
      errorText: '',
      choicesMessages: {},
    };
  });
  it('should render a FormControl with RadioGroup choices', () => {
    const wrapper = shallow(<CustomRadioButton {...props} />);
    expect(wrapper.find(FormControl)).toHaveLength(1);
    expect(wrapper.find(FormLabel)).toHaveLength(1);
    expect(wrapper.find(RadioGroup)).toHaveLength(1);
    wrapper.find(RadioGroup).simulate('change', {}, 'yes');
    expect(props.handleChange).toHaveBeenCalledWith(true);
    wrapper.find(RadioGroup).simulate('change', {}, 'no');
    expect(props.handleChange).toHaveBeenCalledWith(false);
    wrapper.find(RadioGroup).simulate('change', {}, 'test');
    expect(props.handleChange).toHaveBeenCalledWith('test');
    expect(wrapper.find(FormControlLabel)).toHaveLength(2);
  });
  it('should mount to check useEffect', () => {
    mount(<CustomRadioButton {...props} />);
  });
  describe('initValue', () => {
    it('should return the new value', () => {
      expect(initValue({})).toBeUndefined();
      expect(initValue(true)).toBe('yes');
      expect(initValue(false)).toBe('no');
      expect(initValue('test')).toBe('test');
    });
  });
});
