import React, { FunctionComponent, useState, useEffect } from 'react';
import { Radio, RadioGroup, FormLabel, FormControlLabel, FormControl } from '@material-ui/core';
import { Props } from './RadioButton.container';

export const CustomRadioButton: FunctionComponent<Props> = props => {
  const { keyLabel, value, muiPropsCustomConf, config, handleChange, choicesMessages } = props;
  const [selected, setSelected] = useState(initValue(value));
  useEffect(() => {
    setSelected(initValue(value));
  }, [value]);
  // Handler to manage the radio button for a bool option yes/no
  const onChangeHandler = (_e: React.ChangeEvent<{}>, value: string) => {
    switch (value) {
      case 'yes':
        return handleChange(true);
      case 'no':
        return handleChange(false);
      default:
        return handleChange(value);
    }
  };

  return (
    <FormControl component="fieldset" fullWidth {...muiPropsCustomConf}>
      <FormLabel component="legend">{keyLabel}</FormLabel>
      <RadioGroup aria-label={keyLabel} name={keyLabel} value={selected} onChange={onChangeHandler} row>
        {config &&
          config.choices &&
          config.choices.map(choice => (
            <FormControlLabel
              value={choice}
              control={<Radio color="default" />}
              label={choicesMessages[choice]}
              key={`${keyLabel}-${choice}`}
            />
          ))}
      </RadioGroup>
    </FormControl>
  );
};

export const initValue = (value: any) => {
  let newValue: string | undefined = undefined;
  if (value === true) {
    newValue = 'yes';
  }
  if (value === false) {
    newValue = 'no';
  }
  if (typeof value == 'string') {
    newValue = value;
  }
  return newValue;
};

export default CustomRadioButton;
