import React from 'react';
import { shallow } from 'enzyme';
import RichTextEditor, { initEditorState } from './RichTextEditor';
import { Editor } from 'react-draft-wysiwyg';
import { FormControl, InputLabel, FormHelperText } from '@material-ui/core';

describe('RichTextEditor', () => {
  let props: any;
  beforeEach(() => {
    props = {
      value: '',
      keyLabel: 'test',
      handleChange: jest.fn(),
      handleToggle: jest.fn(),
      valid: true,
      touched: true,
      errorText: 'This field is required',
      classes: {
        invalid: 'invalid',
        toolbar: 'toolbar',
        hide: 'hide',
        wrapper: 'wrapper',
        editor: 'editor',
        shrinkLabel: 'shrinkLabel',
        focus: 'focus',
      },
      validation: {
        required: true,
      },
    };
  });
  it('should display a Rich Text Editor', () => {
    const wrapper = shallow(<RichTextEditor {...props} />);
    expect(wrapper.find(FormControl)).toHaveLength(1);
    expect(wrapper.find(InputLabel)).toHaveLength(1);
    expect(wrapper.find(FormHelperText)).toHaveLength(0);
    expect(wrapper.find(Editor)).toHaveLength(1);
    expect(wrapper.find(Editor).props().wrapperClassName).toBe('wrapper');
    expect(wrapper.find(Editor).props().toolbarClassName).toBe('toolbar');
  });
  it('should display a Rich Text Editor with error message', () => {
    props.valid = false;
    const wrapper = shallow(<RichTextEditor {...props} />);
    expect(wrapper.find(FormControl)).toHaveLength(1);
    expect(wrapper.find(InputLabel)).toHaveLength(1);
    expect(wrapper.find(FormHelperText)).toHaveLength(1);
    expect(wrapper.find(Editor)).toHaveLength(1);
    expect(wrapper.find(Editor).props().wrapperClassName).toBe('wrapper invalid');
    expect(wrapper.find(Editor).props().toolbarClassName).toBe('toolbar invalid');
  });
  it('should manage focus and blur', () => {
    const wrapper = shallow(<RichTextEditor {...props} />);
    const RTEEditor = wrapper.find(Editor);
    RTEEditor.simulate('focus');
    expect(props.handleToggle).toHaveBeenCalledWith('focus');
    RTEEditor.simulate('blur');
    expect(props.handleToggle).toHaveBeenCalledWith('blur');
  });
});
