import React, { FunctionComponent, useState, useEffect } from 'react';
import Paper from '@material-ui/core/Paper';
import InputBase from '@material-ui/core/InputBase';
import IconButton from '@material-ui/core/IconButton';
import Typography from '@material-ui/core/Typography';
import Icon from '@material-ui/core/Icon';
import SearchIcon from '@material-ui/icons/Search';

import Props from './SearchBar.interface';

export const textFieldOrArea: FunctionComponent<Props> = props => {
  const { classes, searchAction, searchPlaceHolder, setSearchTermAction, searchTitle, searchClearButtonLabel } = props;
  const [searchTerm, setSearchTerm] = useState('');

  useEffect(() => {
    setSearchTermAction(searchTerm);
  }, [searchTerm]);

  const handleChange = (event: any) => {
    setSearchTerm(event.target.value);
  };

  const handleKeyPress = (target: any) => {
    if (target.charCode == 13) {
      searchAction();
    }
  };

  const handleClick = () => {
    searchAction();
  };

  const handleClear = () => {
    setSearchTerm('');
    setTimeout(() => {
      searchAction();
    }, 200);
  };

  return (
    <>
      <div className={classes.header}>
        <Typography variant="h5" component="h3" className={classes.headerTitle}>
          {searchTitle}
        </Typography>
        <IconButton color="secondary" className={classes.resetButton} onClick={handleClear}>
          <Typography variant="caption" className={classes.resetButtonLabel}>
            {searchClearButtonLabel}
          </Typography>
          <Icon>cached</Icon>
        </IconButton>
      </div>
      <Paper className={classes.root} elevation={1}>
        <InputBase
          id="input"
          onKeyPress={handleKeyPress}
          className={classes.input}
          placeholder={searchPlaceHolder}
          value={searchTerm}
          onChange={handleChange}
        />
        <IconButton id="search-button" className={classes.searchButton} aria-label="Search" onClick={handleClick}>
          <SearchIcon />
        </IconButton>
      </Paper>
    </>
  );
};

export default textFieldOrArea;
