import React, { FunctionComponent } from 'react';
import MenuItem from '@material-ui/core/MenuItem';
import TextField from '@material-ui/core/TextField';
import { Props } from './Selectfield.interface';

export const selectFieldCustom: FunctionComponent<Props> = props => (
  <TextField
    select
    id={`${props.keyLabel}-input`}
    {...props.muiPropsCustomConf}
    value={props.value}
    label={props.keyLabel}
    fullWidth
    onChange={e => props.handleChange(e.target.value)}
    onBlur={() => props.handleToggle && props.handleToggle('blur')}
    onFocus={() => props.handleToggle && props.handleToggle('focus')}
    error={props.touched && !props.valid}
    helperText={props.touched && !props.valid && props.errorText}
    SelectProps={{
      // To show the list below the select field
      MenuProps: {
        getContentAnchorEl: null,
        anchorOrigin: {
          vertical: 'bottom',
          horizontal: 'left',
        },
      },
      displayEmpty: true,
    }}
    InputLabelProps={{
      shrink: true, // We display an empty menu item so shrink need to be true
    }}
  >
    <MenuItem value="" disabled>
      Select...
    </MenuItem>
    {props.backCodes &&
      props.backCodes[props.inputKey] &&
      props.backCodes[props.inputKey].map((choice: string) => (
        <MenuItem value={choice} key={`${props.keyLabel}-${choice}`}>
          {props.messagesFromBack[choice]}
        </MenuItem>
      ))}
  </TextField>
);

export default selectFieldCustom;
