import React, { FunctionComponent } from 'react';
import TextField from '@material-ui/core/TextField';
import InputAdornment from '@material-ui/core/InputAdornment';
import { Props } from './TextFieldOrArea.container';

export const textFieldOrArea: FunctionComponent<Props> = props => {
  let InputProps: any = { value: props.value };
  InputProps = props.muiPropsCustomConf && { ...InputProps, ...props.muiPropsCustomConf.InputProps };
  InputProps = { ...InputProps, classes: { root: props.readOnly ? props.classes.inputReadOnly : props.classes.input } };
  // We manage the adornment if we have one in props
  if (props.adornment && props.adornment.position === 'start') {
    InputProps = {
      ...InputProps,
      fullWidth: false, // To deal with the adornment padding
      startAdornment: <InputAdornment position="start">{props.adornment.value}</InputAdornment>,
    };
  }
  if (props.adornment && props.adornment.position === 'end') {
    InputProps = {
      ...InputProps,
      fullWidth: false, // To deal with the adornment padding
      endAdornment: <InputAdornment position="end">{props.adornment.value}</InputAdornment>,
    };
  }
  const disabled = props.disabled ? props.disabled : false;
  const readOnly = props.readOnly ? props.readOnly : false;
  const error = props.touched && !props.valid && disabled && readOnly;

  return (
    <TextField
      id={`${props.keyLabel}-input`}
      {...props.muiPropsCustomConf}
      placeholder={props.placeholder}
      label={props.keyLabel}
      fullWidth
      onClick={props.onClick}
      type={(props.config && props.config.type) || 'text'}
      onChange={e => props.handleChange(e.target.value)}
      onBlur={() => props.handleToggle('blur')}
      onFocus={() => props.handleToggle('focus')}
      error={error}
      helperText={error && props.errorText}
      InputLabelProps={{ shrink: true }}
      InputProps={InputProps}
    />
  );
};

export default textFieldOrArea;
