import React, { FunctionComponent } from 'react';
import { Props, ButtonType } from './Footer.interface';
import { Grid, Button, Icon } from '@material-ui/core';
import { format } from 'date-fns';
import { HashLink as Link } from 'react-router-hash-link';

export const footer: FunctionComponent<Props> = props => {
  return (
    <Grid container justify="space-between" className={props.classes.footer}>
      <Grid item>
        {props.leftArrow && (
          <Button
            variant="contained"
            // @ts-ignore
            component={Link}
            to={props.leftArrow}
          >
            <Icon>arrow_back</Icon>
          </Button>
        )}
      </Grid>
      <Grid item>
        <Grid container alignItems="center" justify="flex-end" className={props.classes.rightPart}>
          {props.lastSaved && (
            <span className={props.classes.lastSaved}>
              <span>{props.lastRecordMessage}</span>
              <br />
              <span>{format(new Date(props.lastSaved), props.format)}</span>
            </span>
          )}
          {props.buttons &&
            props.buttons.map((button: ButtonType) => (
              <Button
                className={button.classe && !button.disabled ? props.classes[button.classe] : undefined}
                variant={button.variant}
                key={`footer-${button.label}-button`}
                onClick={button.action}
                disabled={button.disabled}
              >
                {props.buttonsMessages[button.label]}
              </Button>
            ))}
          {props.rightArrow && (
            <Button
              variant="contained"
              // @ts-ignore
              component={Link}
              to={props.rightArrow}
            >
              <Icon>arrow_forward</Icon>
            </Button>
          )}
        </Grid>
      </Grid>
    </Grid>
  );
};

export default footer;
