import React from 'react';
import Notifier from './Notifier';
import { shallow, mount } from 'enzyme';

describe('<Notifier>', () => {
  describe('render', () => {
    it('should render null', () => {
      const props = {
        classes: {},
      } as any;
      const wrapper = shallow(<Notifier {...props} />);
      expect(wrapper.text()).toEqual('');
    });
  });

  describe('push notification', () => {
    it('should add 0 notification when store is empty', () => {
      const props = {
        enqueueSnackbar: jest.fn(),
        deleteOneNotificationEffect: jest.fn(),
        notifications: [],
      } as any;
      const wrapper = mount(<Notifier {...props} />);
      expect(props.enqueueSnackbar).toBeCalledTimes(0);
      expect(props.enqueueSnackbar).toBeCalledTimes(0);
    });

    it('should add 1 notification when store contains an array of 1 and delete it from store', () => {
      const props = {
        enqueueSnackbar: jest.fn(),
        deleteOneNotificationEffect: jest.fn(),
        notificationsCenterTranslates: {},
        notifications: [
          {
            key: 1556292840235.0632,
            message: ['savePR_error', 'PR-0000000008'],
            type: 'error',
          },
        ],
      } as any;
      const wrapper = mount(<Notifier {...props} />);
      wrapper.setProps({ notifications: [{ key: 123, message: ['Hello snackbar'], type: 'success' }] });
      expect(props.enqueueSnackbar).toBeCalledTimes(1);
      expect(props.enqueueSnackbar).toHaveBeenNthCalledWith(1, 'savePR_errorPR-0000000008', { variant: 'error' });
      expect(props.deleteOneNotificationEffect).toBeCalledTimes(1);
      expect(props.deleteOneNotificationEffect).toHaveBeenNthCalledWith(1, 1556292840235.0632);
    });

    it('should display translate when existing else text', () => {
      const props = {
        enqueueSnackbar: jest.fn(),
        deleteOneNotificationEffect: jest.fn(),
        notificationsCenterTranslates: {
          savePR_error: 'Error while saving Purcahse Request ',
        },
        notifications: [
          {
            key: 1556292840235.0632,
            message: ['savePR_error', 'PR-0000000008'],
            type: 'error',
          },
        ],
      } as any;
      const wrapper = mount(<Notifier {...props} />);
      wrapper.setProps({ notifications: [{ key: 123, message: ['Hello snackbar'], type: 'success' }] });
      expect(props.enqueueSnackbar).toBeCalledTimes(1);
      expect(props.enqueueSnackbar).toHaveBeenNthCalledWith(1, 'Error while saving Purcahse Request PR-0000000008', {
        variant: 'error',
      });
      expect(props.deleteOneNotificationEffect).toBeCalledTimes(1);
      expect(props.deleteOneNotificationEffect).toHaveBeenNthCalledWith(1, 1556292840235.0632);
    });

    it('should push several notifications when several are in store', () => {
      const props = {
        enqueueSnackbar: jest.fn(),
        deleteOneNotificationEffect: jest.fn(),
        notificationsCenterTranslates: {
          savePR_error: 'Error while saving Purcahse Request ',
        },
        notifications: [
          {
            key: 1556292840235.0632,
            message: ['savePR_error', 'PR-0000000008'],
            type: 'error',
          },
          {
            key: 25,
            message: ['text', 'PR-g'],
            type: 'success',
          },
          {
            key: 32,
            message: ['text12', 'PR-fdfd'],
            type: 'info',
          },
          {
            key: 124,
            message: ['textddsfdf', 'PR-fdf'],
            type: 'warning',
          },
        ],
      } as any;
      const wrapper = mount(<Notifier {...props} />);
      wrapper.setProps({ notifications: [{ key: 123, message: ['Hello snackbar'], type: 'success' }] });
      expect(props.enqueueSnackbar).toBeCalledTimes(4);
      expect(props.deleteOneNotificationEffect).toBeCalledTimes(4);
    });
  });
});
