import React, { FunctionComponent, useState, useEffect } from 'react';
import { NotifierProps } from './Notifier.interface';
import { useSnackbar } from 'notistack';

export const Notifier: FunctionComponent<NotifierProps> = props => {
  const { notifications } = props;

  useEffect(() => {
    const { enqueueSnackbar, deleteOneNotificationEffect, notificationsCenterTranslates } = props;
    notifications.forEach(notification => {
      const messagesArray = notification.message;
      let rebuiltMessage = '';
      messagesArray.forEach((message: string) => {
        let translatedMessage = message;
        if (typeof notificationsCenterTranslates[message] !== 'undefined') {
          translatedMessage = notificationsCenterTranslates[message];
        }
        rebuiltMessage = `${rebuiltMessage}${translatedMessage}`;
      });
      enqueueSnackbar(rebuiltMessage, { variant: notification.type });
      deleteOneNotificationEffect(notification.key);
    });
  }, [notifications]);

  return null;
};

export default Notifier;
