import React from 'react';
import { shallow, mount } from 'enzyme';
import Home, { taskRowClickHandler } from './Home';
import Button from '@material-ui/core/Button';
import Table from '../../commons/table';
import createRouterContext from 'react-router-test-context';
import { Props } from './Home.container';

describe('Home', () => {
  let props: Props;
  beforeEach(() => {
    const context = createRouterContext();
    props = {
      ...context,
      fetchAllTasks: jest.fn(),
      fetchAllPRs: jest.fn(),
      setActiveTask: jest.fn(),
      findPREffect: jest.fn(),
      createPREffect: jest.fn(),
      history: {
        push: jest.fn(),
      },
      createPRButtonMessage: 'Create a request',
      tasksTableMessages: {
        name: 'name',
        beneficiary: 'beneficiary',
        payer: 'payer',
        UserTask_CreatePurchaseRequest: 'Creation',
      },
      userTasks: [
        {
          platformRequest: {
            backendBusinessKey: 'backendBusinessKey',
            businessKey: 'businessKey',
          },
          purchaseRequest: {
            projectName: 'test',
            beneficiaryUserId: 'beneficiaryUserId',
            paymentEntityCode: 'paymentEntityCode',
          },
          task: {
            name: 'UserTask_CreatePurchaseRequest',
          },
        },
      ],
    };
  });
  it('should generate home page', () => {
    const wrapper = shallow(<Home {...props} />);
    expect(wrapper.find(Button)).toHaveLength(1);
    expect(wrapper.find(Table)).toHaveLength(1);
  });
  it('should fetch Tasks and PRs', () => {
    mount(<Home {...props} />);
    expect(props.fetchAllPRs).toHaveBeenCalled();
    expect(props.fetchAllTasks).toHaveBeenCalled();
  });
  it('should create a request', () => {
    const wrapper = shallow(<Home {...props} />);
    expect(props.createPREffect).toBeCalledTimes(0);
    wrapper
      .find(Button)
      .first()
      .simulate('click');
    expect(props.createPREffect).toHaveBeenCalledTimes(1);
  });
  it('should push to validation screen', () => {
    props.userTasks[0].task.name = 'UserTask_ApproverValidation';
    taskRowClickHandler(0, props);
    expect(props.setActiveTask).toHaveBeenCalled();
    expect(props.history.push).toHaveBeenCalledWith(
      `/validation/${props.userTasks[0].platformRequest.backendBusinessKey}`,
    );
  });
  it('should push to validation screen', () => {
    props.userTasks[0].task.name = 'UserTask_PublishProposalRequest';
    taskRowClickHandler(0, props);
    expect(props.setActiveTask).toHaveBeenCalled();
    expect(props.history.push).toHaveBeenCalledWith(
      `/purchase/${props.userTasks[0].platformRequest.backendBusinessKey}/summary?panel=publication`,
    );
  });
  it('should push to validation screen', () => {
    props.userTasks[0].task.name = 'UserTask_CreatePurchaseRequest';
    taskRowClickHandler(0, props);
    expect(props.setActiveTask).toHaveBeenCalled();
    expect(props.history.push).toHaveBeenCalledWith(
      `/purchase/${props.userTasks[0].platformRequest.backendBusinessKey}#prDescriptionSection`,
    );
  });
});
