import React, { FunctionComponent, useEffect, useState } from 'react';
import { Button } from '@material-ui/core';
import Table from '../../commons/table';
import { Props } from './Home.container';
import { isEqual, sortBy } from 'lodash';

export const home: FunctionComponent<Props> = props => {
  const { userTasks, createPRButtonMessage, tasksTableMessages } = props;
  const { fetchAllTasks, fetchAllPRs, createPREffect } = props;
  const [tasksTableBody, setTasksTablebody]: any[] = useState([]);
  useEffect(() => {
    fetchAllTasks();
    fetchAllPRs();
  }, []);

  // We update the content of tasks array when we have them
  useEffect(() => {
    let newTasksTableBody: any[] = [];
    userTasks.length > 0 &&
      userTasks.map(task => {
        let taskRow = [
          task.platformRequest.backendBusinessKey,
          task.purchaseRequest.projectName !== null ? task.purchaseRequest.projectName : '',
          task.purchaseRequest.beneficiaryUserId !== null ? task.purchaseRequest.beneficiaryUserId : '',
          task.purchaseRequest.paymentEntityCode !== null ? task.purchaseRequest.paymentEntityCode : '',
          tasksTableMessages[task.task.name],
        ];
        newTasksTableBody.push(taskRow);
      });
    const arraysAreDifferent = !isEqual(sortBy(tasksTableBody), sortBy(newTasksTableBody));
    if (arraysAreDifferent) {
      setTasksTablebody(newTasksTableBody);
    }
  });

  return (
    <>
      <Button variant="contained" onClick={createPREffect}>
        {createPRButtonMessage}
      </Button>
      <Table
        id="tasks-table"
        tableHead={[
          'ID',
          tasksTableMessages['name'],
          tasksTableMessages['beneficiary'],
          tasksTableMessages['payer'],
          'Type',
        ]}
        tableBody={tasksTableBody}
        rowClickHandler={(i: number) => taskRowClickHandler(i, props)}
      />
    </>
  );
};

export const taskRowClickHandler = (i: number, props: Props) => {
  const taskClicked = props.userTasks[i];
  const prId = taskClicked.platformRequest.backendBusinessKey;
  props.setActiveTask(taskClicked);
  // If this is a validation task we push to the validation screen
  if (taskClicked.task.name === 'UserTask_ApproverValidation') {
    props.history.push(`/validation/${prId}`);
  }
  // If this is a publication task we push to the publication screen
  if (taskClicked.task.name === 'UserTask_PublishProposalRequest') {
    props.history.push(`/purchase/${prId}/summary?panel=publication`);
  }
  // If it is a creation task we can edit the PR
  if (taskClicked.task.name === 'UserTask_CreatePurchaseRequest') {
    props.history.push(`/purchase/${prId}#prDescriptionSection`);
  }
};

export default home;
