import React from 'react';
import { shallow } from 'enzyme';
import PurchaseRequest, { initTabs } from './PurchaseRequest';
import { Grid } from '@material-ui/core';
import PRFooter from './pr-footer';
import { Switch, Route } from 'react-router';
import Loader from './../loader';
import createRouterContext from 'react-router-test-context';
import { Props } from './PurchaseRequest.container';

describe('PurchaseRequest', () => {
  let props: Props;
  beforeEach(() => {
    const context = createRouterContext();
    props = {
      ...context,
      history: {
        push: jest.fn(),
      },
      match: {
        isExact: true,
        params: {
          PRID: 'PR-0000000001',
        },
      },
      activePR: null,
      informationModel: {
        section: {
          any: 'anything',
        },
      },
      findPRWithID: jest.fn(),
      loader: false,
    };
  });
  it('should show a loader', () => {
    props.loader = true;
    const wrapper = shallow(<PurchaseRequest {...props} />);
    expect(wrapper.find(Loader)).toHaveLength(1);
  });
  it('should generate the /purchase page', () => {
    props.activePR = {
      prId: 'PR-0000000011',
      status: 'DRAFT',
    };
    const wrapper = shallow(<PurchaseRequest {...props} />);
    expect(wrapper.find(Grid)).toHaveLength(3);
    expect(wrapper.find(Switch)).toHaveLength(1);
    expect(wrapper.find(Route)).toHaveLength(6);
    expect(wrapper.find(PRFooter)).toHaveLength(1);
  });
});
describe('initTabs', () => {
  it('should return the tabs config when given a prId', () => {
    const prId = 'PR-000000011';
    const expectedTabs = [
      {
        label: 'prDescriptionSection',
        route: `/purchase/${prId}#prDescriptionSection`,
        value: `/purchase/${prId}#prDescriptionSection`,
      },
      {
        label: 'prConsultationRules',
        route: `/purchase/${prId}#prConsultationRules`,
        value: `/purchase/${prId}#prConsultationRules`,
      },
      {
        label: 'prFileUploadSection',
        route: `/purchase/${prId}#prFileUploadSection`,
        value: `/purchase/${prId}#prFileUploadSection`,
      },
      {
        label: 'prSpecificationSection',
        route: `/purchase/${prId}#prSpecificationSection`,
        value: `/purchase/${prId}#prSpecificationSection`,
      },
      {
        label: 'suppliersSelection',
        route: `/purchase/${prId}/suppliers`,
        value: `/purchase/${prId}/suppliers`,
      },
      {
        label: 'summary',
        route: `/purchase/${prId}/summary?panel=validation`,
        value: `/purchase/${prId}/summary`,
      },
    ];
    expect(initTabs(prId, 'DRAFT')).toEqual(expectedTabs);
  });
});
