import React, { FunctionComponent, useEffect, useState } from 'react';
import { Grid } from '@material-ui/core';
import PRFooter from './pr-footer';
import Loader from './../loader';
import { Props } from './PurchaseRequest.container';
import TabMenu from '../../commons/navigation/tab-menu';
import styles from './PurchaseRequest.module.css';
import PrForm from './pr-form';
import { Switch, Route, Redirect } from 'react-router';
import Summary from '../summary';
import SuppliersList from '../../commons/SuppliersList';

export const purchaseRequest: FunctionComponent<Props> = props => {
  const [tabs, setTabs]: any = useState(null);
  // If the user goes directly on this page we check if the PR exists
  useEffect(() => {
    const matchPrId = props.match ? props.match.params.PRID : null;
    if (props.activePR === null || props.activePR.prId !== matchPrId) {
      matchPrId && props.findPR(matchPrId);
    }
    return () => {
      props.resetPurchase();
    };
  }, []);

  useEffect(() => {
    if (props.activePR) {
      const status = props.activePR.status;
      if (status === 'DRAFT' || status === 'PENDING_PUBLICATION') {
        setTabs(initTabs(props.activePR.prId, status));
        props.updatePR(props.activePR);
      } else {
        props.resetPurchase();
        props.history.push('/');
      }
    }
  }, [props.activePR]);

  const appHeader: HTMLElement | null = document.getElementById('app-header');
  const appHeaderHeight: number = appHeader ? appHeader.offsetHeight : 0;

  return !props.loader ? (
    <>
      <Grid container>
        <Grid item xs={12} className={styles.TabMenu}>
          {tabs && <TabMenu tabs={tabs} offset={appHeaderHeight} />}
        </Grid>
        <Switch>
          <Route exact path="/purchase/:PRID/summary" component={Summary} />
          <Route exact path="/purchase/:PRID/suppliers" component={SuppliersList} />
          <Route exact path="/purchase/:PRID/readonly" />
          <Route exact path="/purchase/:PRID/offersevaluation" />
          <Route exact path="/purchase/:PRID/offersevaluation/control" />
          <Route exact path="/purchase/:PRID" component={PrForm} />
          <Redirect to="/purchase/:PRID#prDescriptionSection" />
        </Switch>
        <Grid item xs={12} className={styles.Footer}>
          <PRFooter />
        </Grid>
      </Grid>
    </>
  ) : (
    <Loader />
  );
};

export default purchaseRequest;

export const initTabs = (prId: string, status: string) => [
  {
    label: 'prDescriptionSection',
    route: `/purchase/${prId}#prDescriptionSection`,
    value: `/purchase/${prId}#prDescriptionSection`,
  },
  {
    label: 'prConsultationRules',
    route: `/purchase/${prId}#prConsultationRules`,
    value: `/purchase/${prId}#prConsultationRules`,
  },
  {
    label: 'prFileUploadSection',
    route: `/purchase/${prId}#prFileUploadSection`,
    value: `/purchase/${prId}#prFileUploadSection`,
  },
  {
    label: 'prSpecificationSection',
    route: `/purchase/${prId}#prSpecificationSection`,
    value: `/purchase/${prId}#prSpecificationSection`,
  },
  {
    label: 'suppliersSelection',
    route: `/purchase/${prId}/suppliers`,
    value: `/purchase/${prId}/suppliers`,
  },
  {
    label: 'summary',
    route:
      status === 'DRAFT' ? `/purchase/${prId}/summary?panel=validation` : `/purchase/${prId}/summary?panel=publication`,
    value: `/purchase/${prId}/summary`,
  },
];
