import React, { FunctionComponent } from 'react';
import { Grid } from '@material-ui/core';
import Title from './title';
import Subsection from './subsection';
import { Props } from './Section.container';
import Paper from '@material-ui/core/Paper';

export const section: FunctionComponent<Props> = props => {
  const isValidSection = (isValid: boolean) => {
    if (props.shouldDisplayValidStyle && isValid) {
      return `${props.classes.validSection} ${props.classes.section}`;
    } else if (props.shouldDisplayValidStyle) {
      return `${props.classes.invalidSection} ${props.classes.section}`;
    } else {
      return `${props.classes.section}`;
    }
  };
  return (
    <Grid item xs={12} className={isValidSection(props.prSpecificationIsValid)} id={props.title}>
      <Grid container>
        <Grid item xs={12}>
          <Title title={props.title} specificationHelperText={props.specificationHelperText} type="section" />
        </Grid>
        <Grid item xs={12}>
          <Paper className={props.classes.paper} elevation={2}>
            {props.subsections &&
              Object.keys(props.subsections).map(subsection => (
                <Subsection
                  key={subsection}
                  title={subsection}
                  section={props.title}
                  {...props.subsections[subsection]}
                />
              ))}
          </Paper>
        </Grid>
      </Grid>
    </Grid>
  );
};

export default section;
