import React from 'react';
import { shallow } from 'enzyme';
import Title from './Title';
import { Grid } from '@material-ui/core';

describe('Title', () => {
  it('should generate a section title', () => {
    const props = {
      title: 'Test',
      specificationHelperText: null,
      type: 'section',
      titleMessages: {},
      classes: {
        sectionTitle: 'sectionTitleTest',
        subsectionTitle: 'subsectionTitleTest',
      },
    };
    const wrapper = shallow(<Title {...props} />);
    expect(wrapper.find(Grid)).toHaveLength(3);
    expect(wrapper.find('h1')).toHaveLength(1);
    expect(wrapper.find('h2')).toHaveLength(0);
    expect(
      wrapper
        .find(Grid)
        .at(1)
        .props().className,
    ).toBe('sectionTitleTest');
  });
  it('should generate a subsection title', () => {
    const props = {
      title: 'Test',
      specificationHelperText: null,
      type: 'subsection',
      titleMessages: {},
      classes: {
        sectionTitle: 'sectionTitleTest',
        subsectionTitle: 'subsectionTitleTest',
      },
    };
    const wrapper = shallow(<Title {...props} />);
    expect(wrapper.find(Grid)).toHaveLength(3);
    expect(wrapper.find('h2')).toHaveLength(1);
    expect(wrapper.find('h1')).toHaveLength(0);
    expect(
      wrapper
        .find(Grid)
        .at(1)
        .props().className,
    ).toBe('subsectionTitleTest');
  });
  it('should not render a title when no type is passed', () => {
    const props = {
      title: 'Test',
      specificationHelperText: null,
      type: '',
      titleMessages: {},
      classes: {
        sectionTitle: 'sectionTitleTest',
        subsectionTitle: 'subsectionTitleTest',
      },
    };
    const wrapper = shallow(<Title {...props} />);
    expect(wrapper.find(Grid)).toHaveLength(3);
    expect(
      wrapper
        .find(Grid)
        .at(1)
        .props().className,
    ).toBeUndefined();
  });
});
