import React from 'react';
import { shallow } from 'enzyme';
import Routes from './Routes';
import PurchasesList from './../home';
import HomePage from '../home-page';
import Loader from './../loader';
import PurchaseRequest from './../purchase-request';
import { Switch, Route, Redirect } from 'react-router';
import Validation from '../validation';
import Publish from '../publish';

describe('Routes', () => {
  it('should set a loader on the begin', () => {
    const props = {
      authentificatedBySafe: null,
      authentificatedByApp: null,
    };
    const wrapper = shallow(<Routes {...props} />);
    expect(wrapper.find(Route)).toHaveLength(1);
    expect(wrapper.containsMatchingElement(<Route path="/" component={Loader} />)).toBeTruthy();
  });

  it('should set the route to home if connected', () => {
    const props = {
      authentificatedBySafe: true,
      authentificatedByApp: true,
    };
    const wrapper = shallow(<Routes {...props} />);
    expect(wrapper.find(Switch)).toHaveLength(1);
    expect(wrapper.find(Route)).toHaveLength(7);
    expect(wrapper.find(Redirect)).toHaveLength(1);
    expect(wrapper.containsMatchingElement(<Route path="/" component={HomePage} />)).toBeTruthy();
    expect(wrapper.containsMatchingElement(<Route path="/publish/:PRID" component={Publish} />)).toBeTruthy();
    expect(wrapper.containsMatchingElement(<Route path="/validation/:PRID" component={Validation} />)).toBeTruthy();
    expect(wrapper.containsMatchingElement(<Route path="/purchase/:PRID" component={PurchaseRequest} />)).toBeTruthy();
    expect(wrapper.containsMatchingElement(<Route path="/synthesis/:PRID" />)).toBeTruthy();
    expect(wrapper.containsMatchingElement(<Route path="/analysis/:PRID" />)).toBeTruthy();
    expect(wrapper.containsMatchingElement(<Route path="/purchases/" component={PurchasesList} />)).toBeTruthy();
  });

  it('should set the error if user has no roles', () => {
    const props = {
      authentificatedBySafe: true,
      authentificatedByApp: false,
    };
    const wrapper = shallow(<Routes {...props} />);
    expect(wrapper.find(Route)).toHaveLength(1);
    // expect(wrapper.containsMatchingElement(
    //   <Route path="/" render={props => <ErrorComp {...props} errorMessage="no-roles" />} />
    // )).toBeTruthy();
  });
});
