import React, { Component } from 'react';
import { Switch, Route, Redirect } from 'react-router';
import PurchasesList from '../home';
import HomePage from '../home-page';
import PurchaseRequest from '../purchase-request';
import Loader from '../loader';
import ErrorComp from '../error';
import Validation from '../validation';
import Publish from '../publish';

interface AppProps {
  authentificatedBySafe: boolean | null;
  authentificatedByApp: boolean | null;
}

export class Routes extends Component<AppProps> {
  render() {
    // By default the route is a loader
    let routes = <Route path="/" component={Loader} />;

    /******************
     * LOGGED IN
     */
    // If the user is authentificated and has roles we show the application
    if (this.props.authentificatedBySafe === true && this.props.authentificatedByApp === true) {
      routes = (
        <Switch>
          <Route exact path="/publish/:PRID" component={Publish} />
          <Route exact path="/validation/:PRID" component={Validation} />
          <Route path="/purchase/:PRID" component={PurchaseRequest} />
          <Route path="/synthesis/:PRID" />
          <Route path="/analysis/:PRID" />
          <Route exact path="/purchases/" component={PurchasesList} />
          <Route exact path="/" component={HomePage} />
          <Redirect to="/" />
        </Switch>
      );
    }
    /****************** */
    /****************** */

    /******************
     * Handle roles here
     */
    /****************** */
    /****************** */

    /******************
     * AUTHENTICATION ERROR
     */
    // Else we show a error component
    if (this.props.authentificatedBySafe && this.props.authentificatedByApp === false) {
      routes = <Route path="/" render={props => <ErrorComp {...props} errorMessage="no-roles" />} />;
    }
    /****************** */
    /****************** */

    return routes;
  }
}

export default Routes;
