import React, { FunctionComponent, useState, useEffect } from 'react';
import Props from './Summary.interface';
import SummaryValidation from './summary-validation';
import SummaryPublication from './summary-publication';
import Grid from '@material-ui/core/Grid';

export const Summary: FunctionComponent<Props> = props => {
  const { classes, summaryLabels, location, history } = props;
  const [openPanel, setOpenPanel]: any = useState(null);
  useEffect(() => {
    const params = new URLSearchParams(location.search);
    if (params.has('panel')) {
      const panel: any = params.get('panel');
      panel !== openPanel && setOpenPanel(panel);
    } else {
      openPanel && setOpenPanel(null);
    }
  }, [location.search]);

  const panelHandler = (panel: string) => {
    if (panel !== openPanel) {
      setOpenPanel(panel);
      history.push(`${location.pathname}?panel=${panel}`);
    } else {
      setOpenPanel(null);
      history.push(location.pathname);
    }
  };
  return (
    <Grid item xs={12}>
      <div className={classes.summaryComponent}>
        <div className={classes.title}>{summaryLabels.summaryTitle}</div>
        <SummaryValidation index={1} openPanel={openPanel} panelHandler={panelHandler} />
        <SummaryPublication index={1} openPanel={openPanel} panelHandler={panelHandler} />
      </div>
    </Grid>
  );
};

export default Summary;
