import React, { StatelessComponent } from 'react';
import Props from './SummaryPublication.interface';
import ExpansionPanel from '@material-ui/core/ExpansionPanel';
import ExpansionPanelSummary from '@material-ui/core/ExpansionPanelSummary';
import ExpansionPanelDetails from '@material-ui/core/ExpansionPanelDetails';
import ExpandMoreIcon from '@material-ui/icons/ExpandMore';
import Grid from '@material-ui/core/Grid';
import Input from '../../../commons/input';
import Button from '@material-ui/core/Button';

export const SummaryPublication: StatelessComponent<Props> = props => {
  const { classes, publicationPanelLabels, inputsReadOnly, activePR, history, match } = props;
  const goToprConsultationRules = () => {
    history.push(`../${match.params.PRID}#prConsultationRules`);
  };
  const firstPartInputs = ['projectName', 'amount'];
  const planningPartInputs = [
    'supplierOfferReceptionDateTime',
    'supplierOralStartDate',
    'supplierOralEndDate',
    'estimatedDateSupplierSelection',
    'estimatedContractSignatureDate',
    'projectStartDate',
    'projectEndDate',
  ];

  return (
    <ExpansionPanel
      classes={{ root: classes.panel }}
      expanded={props.openPanel === 'publication'}
      onChange={() => props.panelHandler('publication')}
    >
      <ExpansionPanelSummary
        classes={{ root: classes.title }}
        expandIcon={<ExpandMoreIcon classes={{ root: classes.icon }} />}
      >
        {publicationPanelLabels.publicationPanelTitle}
      </ExpansionPanelSummary>
      <ExpansionPanelDetails className={classes.panelDetails}>
        <Grid className={classes.grid} container spacing={8}>
          <div className={classes.subTitle}>{publicationPanelLabels.publicationPanelSubTitle}</div>
          {firstPartInputs.map((inputKey: string, index: number) => (
            <Grid key={`summaryPublication-${index}-${inputKey}`} item xs={3}>
              <Input keyLabel={inputKey} value={activePR[inputKey]} {...inputsReadOnly[inputKey]} />
            </Grid>
          ))}
          <div className={classes.subTitle}>{publicationPanelLabels.publicationPlanningPanelTitle}</div>
          {planningPartInputs.map((inputKey: string, index: number) => (
            <Grid key={`summaryPublicationPlanning-${index}-${inputKey}`} item xs={3}>
              <Input keyLabel={inputKey} value={activePR[inputKey]} {...inputsReadOnly[inputKey]} />
            </Grid>
          ))}
        </Grid>
        <Button onClick={goToprConsultationRules} variant="outlined" className={classes.button}>
          {publicationPanelLabels.modifyDateButtonPublication}
        </Button>
        <div className={classes.subTitle}>{publicationPanelLabels.attachmentPublicationPanelTitle}</div>
        <div className={classes.subTitle}>{publicationPanelLabels.suppliersPublicationPanelTitle}</div>
      </ExpansionPanelDetails>
    </ExpansionPanel>
  );
};

export default SummaryPublication;
