import React, { StatelessComponent } from 'react';
import Props from './SummaryValidation.interface';
import Validators from './summary-validators';

import ExpansionPanel from '@material-ui/core/ExpansionPanel';
import ExpansionPanelSummary from '@material-ui/core/ExpansionPanelSummary';
import ExpansionPanelDetails from '@material-ui/core/ExpansionPanelDetails';
import ExpandMoreIcon from '@material-ui/icons/ExpandMore';
import Grid from '@material-ui/core/Grid';
import Table from '../../../commons/table';
import Input from '../../../commons/input';
import Button from '@material-ui/core/Button';

export const SummaryValidation: StatelessComponent<Props> = props => {
  const {
    classes,
    validationPanelLabels,
    inputsReadOnly,
    fileUploadMessages,
    activePR,
    validationProcess,
    history,
    match,
  } = props;

  const goToprDescriptionSections = () => {
    history.push(`../${match.params.PRID}#prDescriptionSection`);
  };
  const filesTableBody = [['Test-01-rempli', 'PDF', '2 MB', 'Interne']];
  const firstPartInputs = [
    'projectName',
    'amount',
    'beneficiaryUserId',
    'projectEntityCode',
    'paymentEntityCode',
    'projectStartDate',
    'projectEndDate',
    'budgeted',
    'contractNatureCode',
    'externalAssistanceComments',
  ];

  return (
    <ExpansionPanel
      classes={{ root: classes.panel }}
      expanded={props.openPanel === 'validation'}
      onChange={() => props.panelHandler('validation')}
    >
      <ExpansionPanelSummary
        classes={{ root: classes.title }}
        expandIcon={<ExpandMoreIcon classes={{ root: classes.icon }} />}
      >
        {validationPanelLabels.validationPanelTitle}
      </ExpansionPanelSummary>
      <ExpansionPanelDetails className={classes.panelDetails}>
        <Grid className={classes.grid} container spacing={8}>
          <div className={classes.subTitle}>{validationPanelLabels.validationPanelSubTitle}</div>
          {firstPartInputs.map((inputKey: string, index: number) => (
            <Grid key={`summaryValidation-${index}-${inputKey}`} item xs={4}>
              <Input keyLabel={inputKey} value={activePR[inputKey]} {...inputsReadOnly[inputKey]} />
            </Grid>
          ))}
        </Grid>
        <Button onClick={goToprDescriptionSections} variant="outlined" className={classes.button}>
          {validationPanelLabels.modifyButtonValidationPanelTitle}
        </Button>
        <div className={classes.subTitle}>{validationPanelLabels.attachmentValidationPanelTitle}</div>
        <Table
          id="fileupload"
          tableHead={[
            fileUploadMessages['fileTabName'],
            fileUploadMessages['fileTabType'],
            fileUploadMessages['fileTabWeight'],
            fileUploadMessages['fileTabDestination'],
          ]}
          tableBody={filesTableBody}
          rowClickHandler={() => {}}
        />
        <div className={classes.subTitle}>{validationPanelLabels.validatorsPanelTitle}</div>
        <Validators index={1} activePR={activePR} validationProcess={validationProcess} />
      </ExpansionPanelDetails>
    </ExpansionPanel>
  );
};

export default SummaryValidation;
