import React, { FunctionComponent } from 'react';
import Props from './SummaryValidators.interface';
import Card from '@material-ui/core/Card';
import Badge from '@material-ui/core/Badge';
import Grid from '@material-ui/core/Grid';
import CardContent from '@material-ui/core/CardContent';

export const summaryValidators: FunctionComponent<Props> = props => {
  const { validationProcess, classes, validatorsLabels } = props;
  const businessApprovals = validationProcess.businessApprovals && validationProcess.businessApprovals;
  const financialApprovals = validationProcess.financialApprovals && validationProcess.financialApprovals;

  return (
    <>
      <Grid item xs={12}>
        <Grid className={classes.grid} container>
          <Grid item xs={5}>
            <div className={classes.subTitle}>{validatorsLabels.businessApprovalsTitle}</div>
            {businessApprovals &&
              businessApprovals.map((element: any, index: number) => (
                <Badge color="primary" badgeContent={index + 1} classes={{ badge: classes.badge }}>
                  <Card classes={{ root: classes.card }}>
                    <CardContent classes={{ root: classes.content }}>
                      <span>{element.userId}</span>
                      <span>{element.userEntityCode}</span>
                    </CardContent>
                  </Card>
                </Badge>
              ))}
          </Grid>
          <Grid item xs={5}>
            <div className={classes.subTitle}>{validatorsLabels.financialApprovalsTitle}</div>
            {financialApprovals &&
              financialApprovals.map((element: any, index: number) => (
                <Badge color="primary" badgeContent={index + 1} classes={{ badge: classes.badge }}>
                  <Card classes={{ root: classes.card }}>
                    <CardContent classes={{ root: classes.content }}>
                      <span>{element.userId}</span>
                      <span>{element.userEntityCode}</span>
                    </CardContent>
                  </Card>
                </Badge>
              ))}
          </Grid>
        </Grid>
      </Grid>
    </>
  );
};

export default summaryValidators;
