import React, { FunctionComponent, useEffect, useState } from 'react';
import { Grid, Button } from '@material-ui/core';
import { Props } from './Validation.container';
import Loader from './../loader';

export const validation: FunctionComponent<Props> = props => {
  const { buttonsMessages, approveTask, match, activePR, findPR } = props;
  const [approvablePR, setApprovablePR] = useState(false);

  // We can't do that yet, there are some issues with camunda. They don't send all
  // the tasks in a PR so we can't check if there is a ApproverValidation's one

  useEffect(() => {
    const matchPrId = match.isExact && match.params.PRID;
    if (props.activePR === null || props.activePR.platformRequest.backendBusinessKey !== matchPrId) {
      findPR(matchPrId);
    }
  }, []);

  useEffect(() => {
    const hasAValidationTask = validationTask(activePR);

    if (activePR && hasAValidationTask === true) {
      setApprovablePR(true);
    }

    // We reroute to the home, will need an error messsage later
    if (activePR && hasAValidationTask === false) {
      props.history.push('/');
    }
  });
  return (
    <Grid container justify="space-evenly" alignItems="center">
      {activePR && approvablePR ? (
        <>
          <Button variant="contained" onClick={approveTask}>
            {buttonsMessages.approve}
          </Button>
          <Button variant="contained">{buttonsMessages.reject}</Button>
          <Button variant="contained" onClick={() => props.history.push('/')}>
            {buttonsMessages.back}
          </Button>
        </>
      ) : (
        <Loader />
      )}
    </Grid>
  );
};

export const validationTask = (activePR: any) => {
  let hasAValidationTask = null;
  activePR &&
    activePR.tasks.map(
      (task: { id: string; name: string }) => (hasAValidationTask = task.name === 'UserTask_ApproverValidation'),
    );
  return hasAValidationTask;
};

export default validation;
