import * as effects from './droppedFiles.effects';
import { actionTypes } from './droppedFiles.actions';
import { requester } from '../../helpers/api';

describe('droppedFiles.effects', () => {
  describe('createDroppedFileModelEffect effect', () => {
    it('should create an object to store for each uploaded file from model - two keys', () => {
      const payload = ['prInternalFiles', 'prExternalFiles'];
      const dispatch = jest.fn();
      const getState = jest.fn(() => ({
        droppedFiles: {},
      }));
      const expectedPayload = {
        prInternalFiles: {
          newFiles: [],
          existingFiles: [],
        },
        prExternalFiles: {
          newFiles: [],
          existingFiles: [],
        },
      };

      effects.createDroppedFileModelEffect(payload)(dispatch, getState);
      expect(dispatch).toBeCalledTimes(1);
      expect(dispatch).toHaveBeenNthCalledWith(1, {
        payload: expectedPayload,
        type: actionTypes.DROPPEDFILES_CREATE_MODEL,
      });
    });

    it('should create an object to store for each uploaded file from model - one key', () => {
      const payload = ['prExternalFiles'];
      const dispatch = jest.fn();
      const getState = jest.fn(() => ({
        droppedFiles: {},
      }));
      const expectedPayload = {
        prExternalFiles: {
          newFiles: [],
          existingFiles: [],
        },
      };

      effects.createDroppedFileModelEffect(payload)(dispatch, getState);
      expect(dispatch).toBeCalledTimes(1);
      expect(dispatch).toHaveBeenNthCalledWith(1, {
        payload: expectedPayload,
        type: actionTypes.DROPPEDFILES_CREATE_MODEL,
      });
    });

    it('should add new key to model with existing keys', () => {
      const payload = ['prExternalFiles'];
      const dispatch = jest.fn();
      const getState = jest.fn(() => ({
        droppedFiles: {
          prInternalFiles: {
            newFiles: [{ file: '3' }, { file: '4' }],
            existingFiles: [{ file: '1' }, { file: '2' }],
          },
        },
      }));
      const expectedPayload = {
        prInternalFiles: {
          newFiles: [{ file: '3' }, { file: '4' }],
          existingFiles: [{ file: '1' }, { file: '2' }],
        },
        prExternalFiles: {
          newFiles: [],
          existingFiles: [],
        },
      };

      effects.createDroppedFileModelEffect(payload)(dispatch, getState);
      expect(dispatch).toBeCalledTimes(1);
      expect(dispatch).toHaveBeenNthCalledWith(1, {
        payload: expectedPayload,
        type: actionTypes.DROPPEDFILES_CREATE_MODEL,
      });
    });

    it('should not edit the model if no key is passed as payload', () => {
      const payload: any[] = [];
      const dispatch = jest.fn();
      const getState = jest.fn(() => ({
        droppedFiles: {},
      }));

      effects.createDroppedFileModelEffect(payload)(dispatch, getState);
      expect(dispatch).toBeCalledTimes(0);
    });
  });

  describe('addDroppedFileEffect effect', () => {
    it('should add files to new files array to inputKey fileDropped location', () => {
      const inputKey: string = 'prInternalFiles';
      const files: any[] = [{ file: '5' }, { file: '6' }];
      const dispatch = jest.fn();
      const getState = jest.fn(() => ({
        droppedFiles: {
          prInternalFiles: {
            newFiles: [{ file: '3' }, { file: '4' }],
            existingFiles: [{ file: '1' }, { file: '2' }],
          },
        },
      }));
      const expectedPayload = {
        prInternalFiles: {
          newFiles: [{ index: 0, file: '5' }, { index: 1, file: '6' }],
          existingFiles: [{ file: '1' }, { file: '2' }],
        },
      };

      effects.addDroppedFileEffect(inputKey, files, 'newFiles')(dispatch, getState);
      expect(dispatch).toBeCalledTimes(1);
      expect(dispatch).toHaveBeenNthCalledWith(1, {
        payload: expectedPayload,
        type: actionTypes.DROPPEDFILES_CREATE_MODEL,
      });
    });

    it('should add files to existing files array to inputKey fileDropped location', () => {
      const inputKey: string = 'prInternalFiles';
      const files: any[] = [{ file: '5' }, { file: '6' }];
      const dispatch = jest.fn();
      const getState = jest.fn(() => ({
        droppedFiles: {
          prInternalFiles: {
            newFiles: [{ file: '3' }, { file: '4' }],
            existingFiles: [{ file: '1' }, { file: '2' }],
          },
        },
      }));
      const expectedPayload = {
        prInternalFiles: {
          newFiles: [{ index: 0, file: '3' }, { index: 1, file: '4' }],
          existingFiles: [{ file: '1' }, { file: '2' }, { file: '5' }, { file: '6' }],
        },
      };

      effects.addDroppedFileEffect(inputKey, files, 'existingFiles')(dispatch, getState);
      expect(dispatch).toBeCalledTimes(1);
      expect(dispatch).toHaveBeenNthCalledWith(1, {
        payload: expectedPayload,
        type: actionTypes.DROPPEDFILES_CREATE_MODEL,
      });
    });
  });

  describe('deleteOneFileByIndexEffect effect', () => {
    it('should remove nothing if file index is not found', () => {
      const inputKey: string = 'prInternalFiles';
      const dispatch = jest.fn();
      const getState = jest.fn(() => ({
        droppedFiles: {
          prInternalFiles: {
            newFiles: [{ index: 0, file: '3' }, { index: 1, file: '4' }, { index: 2, file: '18' }],
            existingFiles: [{ file: '1' }, { file: '2' }],
          },
        },
      }));
      const expectedPayload = {
        prInternalFiles: {
          newFiles: [{ index: 0, file: '3' }, { index: 1, file: '4' }, { index: 2, file: '18' }],
          existingFiles: [{ file: '1' }, { file: '2' }],
        },
      };

      effects.deleteOneFileByIndexEffect(inputKey, 12)(dispatch, getState);
      expect(dispatch).toBeCalledTimes(1);
      expect(dispatch).toHaveBeenNthCalledWith(1, {
        payload: expectedPayload,
        type: actionTypes.DROPPEDFILES_DELETE_NEW_FILE_BY_INDEX,
      });
    });
    it('should remove one file by index from newFiles', () => {
      const inputKey: string = 'prInternalFiles';
      const dispatch = jest.fn();
      const getState = jest.fn(() => ({
        droppedFiles: {
          prInternalFiles: {
            newFiles: [{ index: 0, file: '3' }, { index: 1, file: '4' }, { index: 2, file: '18' }],
            existingFiles: [{ file: '1' }, { file: '2' }],
          },
        },
      }));
      const expectedPayload = {
        prInternalFiles: {
          newFiles: [{ index: 0, file: '3' }, { index: 2, file: '18' }],
          existingFiles: [{ file: '1' }, { file: '2' }],
        },
      };

      effects.deleteOneFileByIndexEffect(inputKey, 1)(dispatch, getState);
      expect(dispatch).toBeCalledTimes(1);
      expect(dispatch).toHaveBeenNthCalledWith(1, {
        payload: expectedPayload,
        type: actionTypes.DROPPEDFILES_DELETE_NEW_FILE_BY_INDEX,
      });
    });
  });

  describe('resetNewFilesEffect effect', () => {
    it('should reset new files to empty array and set existing file', () => {
      const inputKey: string = 'prInternalFiles';
      const dispatch = jest.fn();
      const getState = jest.fn(() => ({
        droppedFiles: {
          prInternalFiles: {
            newFiles: [{ index: 0, file: '3' }, { index: 1, file: '4' }, { index: 2, file: '18' }],
            existingFiles: [{ file: '1' }, { file: '2' }],
          },
        },
      }));
      const expectedPayload = {
        prInternalFiles: {
          newFiles: [],
          existingFiles: [{ file: '1' }, { file: '2' }],
        },
      };

      effects.resetNewFilesEffect(inputKey)(dispatch, getState);
      expect(dispatch).toBeCalledTimes(1);
      expect(dispatch).toHaveBeenNthCalledWith(1, {
        payload: expectedPayload,
        type: actionTypes.DROPPEDFILES_RESET_NEW_FILES,
      });
    });
  });

  describe('getExistingFilesEffect effect', () => {
    let getSuccessMockData: {};

    beforeEach(() => {
      getSuccessMockData = [
        {
          documentType: 'attachment',
          format: 'jpg',
          id: '0000000240',
          name: 'Koala.jpg',
          personalData: true,
          purchaseRequestId: 'PR-0000000002',
          sharingStatus: 'external_document',
          size: '780831',
        },
        {
          documentType: 'attachment',
          format: 'jpg',
          id: '0000000241',
          name: 'Jellyfish.jpg',
          personalData: true,
          purchaseRequestId: 'PR-0000000002',
          sharingStatus: 'internal_document',
          size: '775702',
        },
      ];
    });
    it('should get existing files with internal_document destination', async () => {
      requester.get = jest.fn(() =>
        Promise.resolve({
          status: 200,
          data: getSuccessMockData,
        }),
      );
      const fieldId: string = 'prInternalFiles';
      const destination: string = 'internal_document';

      const dispatch = jest.fn();
      const getState = jest.fn(() => ({
        droppedFiles: {
          prInternalFiles: {
            newFiles: [{ index: 0, file: '3' }, { index: 1, file: '4' }, { index: 2, file: '18' }],
            existingFiles: [{ file: '1' }, { file: '2' }],
          },
        },
        purchaseRequests: {
          activePR: {
            prId: 'PR-000000245',
          },
        },
      }));
      const expectedPayload = {
        prInternalFiles: {
          newFiles: [{ index: 0, file: '3' }, { index: 1, file: '4' }, { index: 2, file: '18' }],
          existingFiles: [
            {
              documentType: 'attachment',
              format: 'jpg',
              id: '0000000241',
              name: 'Jellyfish.jpg',
              personalData: true,
              purchaseRequestId: 'PR-0000000002',
              sharingStatus: 'internal_document',
              size: '775702',
            },
          ],
        },
      };

      await effects.getExistingFilesEffect(fieldId, destination)(dispatch, getState);
      expect(dispatch).toBeCalledTimes(1);
      expect(dispatch).toHaveBeenNthCalledWith(1, {
        payload: expectedPayload,
        type: actionTypes.DROPPEDFILES_GET_EXISTING_FILES,
      });
    });
  });

  describe('createOneFileInEDM effect', () => {
    let postSuccessMockData: {};

    beforeEach(() => {
      postSuccessMockData = [
        {
          documentType: 'attachment',
          format: 'jpg',
          id: '0000000241',
          name: 'Jellyfish.jpg',
          personalData: true,
          purchaseRequestId: 'PR-0000000002',
          sharingStatus: 'internal_document',
          size: '775702',
        },
      ];
    });
    it('should call create one file WS', async () => {
      requester.post = jest.fn(() =>
        Promise.resolve({
          status: 200,
          data: postSuccessMockData,
        }),
      );

      const dispatch = jest.fn();

      const expectedPayload = {
        prInternalFiles: {
          newFiles: [{ index: 0, file: '3' }, { index: 1, file: '4' }, { index: 2, file: '18' }],
          existingFiles: [
            {
              documentType: 'attachment',
              format: 'jpg',
              id: '0000000241',
              name: 'Jellyfish.jpg',
              personalData: true,
              purchaseRequestId: 'PR-0000000002',
              sharingStatus: 'internal_document',
              size: '775702',
            },
          ],
        },
      };

      await effects.createOneFileInEDM(
        {
          name: '',
          purchaseRequestId: '',
          sharingStatus: '',
          personalData: '',
          file: {},
          documentType: '',
        },
        'prInternalFiles',
      )(dispatch);
      expect(dispatch).toBeCalledTimes(1);
    });
  });

  describe('createFileInEDM effect', () => {
    let postSuccessMockData: {};

    beforeEach(() => {
      postSuccessMockData = [
        {
          documentType: 'attachment',
          format: 'jpg',
          id: '0000000241',
          name: 'Jellyfish.jpg',
          personalData: true,
          purchaseRequestId: 'PR-0000000002',
          sharingStatus: 'internal_document',
          size: '775702',
        },
      ];
    });
    it('should dispatch 3 times for each file', async () => {
      requester.post = jest.fn(() =>
        Promise.resolve({
          status: 200,
          data: postSuccessMockData,
        }),
      );
      const fieldId: string = 'prInternalFiles';
      const destination: string = 'internal_document';

      const dispatch = jest.fn();
      const getState = jest.fn(() => ({
        droppedFiles: {
          prInternalFiles: {
            newFiles: [{ index: 0, file: '3' }, { index: 1, file: '4' }, { index: 2, file: '18' }],
            existingFiles: [{ file: '1' }, { file: '2' }],
          },
        },
        purchaseRequests: {
          activePR: {
            prId: 'PR-000000245',
          },
        },
      }));
      const expectedPayload = {
        prInternalFiles: {
          newFiles: [{ index: 0, file: '3' }, { index: 1, file: '4' }, { index: 2, file: '18' }],
          existingFiles: [
            {
              documentType: 'attachment',
              format: 'jpg',
              id: '0000000241',
              name: 'Jellyfish.jpg',
              personalData: true,
              purchaseRequestId: 'PR-0000000002',
              sharingStatus: 'internal_document',
              size: '775702',
            },
          ],
        },
      };

      await effects.createFileInEDM('prInternalFiles', '', '', '')(dispatch, getState);
      expect(dispatch).toBeCalledTimes(9);
    });
  });

  describe('downloadSingleFileEffect effect', () => {
    let getSuccessMockData: {};

    beforeEach(() => {
      getSuccessMockData = 'file content';
    });
    it('should get file content from WS', async () => {
      requester.get = jest.fn(() => Promise.resolve({ data: getSuccessMockData }));
      const fileURL = 'purchases/PR1/spec/generate/docx?ln=fr';
      const fileName = 'Report.docx';

      const dispatch = jest.fn();
      const getState = jest.fn(() => ({
        purchaseRequests: {
          activePR: {
            prId: 'PR18',
          },
        },
      }));
      expect(requester.get).toBeCalledTimes(0);
      const res = await effects.downloadSingleFileEffect(fileURL, fileName)(dispatch, getState);
      expect(requester.get).toBeCalledTimes(1);
    });
  });

  describe('downloadSpecificationFileEffect effect', () => {
    let getSuccessMockData: {};

    beforeEach(() => {
      getSuccessMockData = 'file content';
    });
    it('should call downloadSingleFileEffect', async () => {
      requester.get = jest.fn(() => Promise.resolve({ data: getSuccessMockData }));
      const fileURL = 'purchases/PR1/spec/generate/docx?ln=fr';
      const fileName = 'Report.docx';

      const dispatch = jest.fn();
      const getState = jest.fn(() => ({
        purchaseRequests: {
          activePR: {
            prId: 'PR18',
          },
        },
        intl: {
          locale: 'fr',
          messages: {
            purchase: {
              titles: {
                prSpecificationSection: 'Cahier des charges',
              },
            },
          },
        },
      }));
      const res = await effects.downloadSpecificationFileEffect()(dispatch, getState);
      expect(dispatch).toBeCalledTimes(1);
    });
  });

  describe('addIndexToDroppedFilesList function', () => {
    it('should return an empty array', () => {
      const files: any[] = [
        { name: 'testFile.jpg', path: 'testFile.jpg' },
        { name: 'anotherTestFile.jpg', path: 'anotherTestFile.jpg' },
      ];
      const expectedPayload: any[] = [
        { index: 0, name: 'testFile.jpg', path: 'testFile.jpg' },
        { index: 1, name: 'anotherTestFile.jpg', path: 'anotherTestFile.jpg' },
      ];

      const ret = effects.addIndexToDroppedFilesList(files);
      expect(ret).toEqual(expectedPayload);
    });
  });
});
