import {
  createDroppedFileModel,
  resetNewFiles,
  deleteNewFileByIndex,
  getExistingFiles,
} from '../droppedFiles/droppedFiles.actions';
import { addOneNotificationEffectWrapper } from '../notifications';
import { requester } from '../../helpers/api';
import { getInputsModelEffect, editInputsModelEffect, getPrValues } from '../prModels';
import fileDownload from 'js-file-download';

export const createDroppedFileModelEffect = (payload: any[]) => (dispatch: any, getState: any) => {
  const droppedFilesState = getState().droppedFiles;
  const droppedFilesStateKeys = Object.keys(droppedFilesState);
  const builtPayload: {
    [key: string]: {
      newFiles: any[];
      existingFiles: any[];
    };
  } = {};
  if (Array.isArray(payload) && payload.length > 0) {
    payload.forEach(droppedFileKey => {
      builtPayload[droppedFileKey] = {
        newFiles: [],
        existingFiles: [],
      };
    });
    const newPayload = { ...droppedFilesState, ...builtPayload };
    dispatch(createDroppedFileModel(newPayload));
  }
};
export const addIndexToDroppedFilesList = (files: any[]) =>
  files.map((file, index) => {
    file.index = index;
    return file;
  });

export const addDroppedFileEffect = (inputKey: string, files: any[], newExisting: string) => (
  // add if again and handle existing files case
  dispatch: any,
  getState: any,
) => {
  const droppedFilesState = getState().droppedFiles && getState().droppedFiles[inputKey];

  if (droppedFilesState && newExisting === 'newFiles' && files.length > 0) {
    const filesWithIndex = addIndexToDroppedFilesList(files);
    droppedFilesState['newFiles'] = filesWithIndex;
    dispatch(
      createDroppedFileModel({
        [inputKey]: {
          newFiles: droppedFilesState.newFiles,
          existingFiles: droppedFilesState.existingFiles,
        },
      }),
    );
  }

  if (droppedFilesState && newExisting !== 'newFiles' && files.length > 0) {
    const filesWithIndex = addIndexToDroppedFilesList(droppedFilesState.newFiles);
    droppedFilesState['newFiles'] = filesWithIndex;
    files.forEach(file => droppedFilesState[newExisting].push(file));
    dispatch(
      createDroppedFileModel({
        [inputKey]: {
          newFiles: droppedFilesState.newFiles,
          existingFiles: droppedFilesState.existingFiles,
        },
      }),
    );
  }
};

export const resetNewFilesEffect = (destination: string) => (dispatch: any, getState: any) => {
  dispatch(
    resetNewFiles({
      [destination]: {
        newFiles: [],
        existingFiles: getState().droppedFiles[destination].existingFiles,
      },
    }),
  );
};

export const deleteOneFileByIndexEffect = (destination: string, index: number) => (dispatch: any, getState: any) => {
  dispatch(
    deleteNewFileByIndex({
      [destination]: {
        newFiles: getState().droppedFiles[destination].newFiles.filter((file: any) => file.index !== index),
        existingFiles: getState().droppedFiles[destination].existingFiles,
      },
    }),
  );
};

export const getExistingFilesEffect = (fieldId: string, destination: string) => async (
  dispatch: any,
  getState: any,
) => {
  const state = getState();
  let newFiles = [];
  if (
    state.droppedFiles &&
    state.droppedFiles[fieldId] &&
    state.droppedFiles[fieldId].newFiles &&
    state.droppedFiles[fieldId].newFiles.length > 0
  ) {
    newFiles = state.droppedFiles[fieldId].newFiles;
  }
  const prId = state.purchaseRequests.activePR.prId;
  try {
    const res: any = await requester.get(`ged/${prId}`);
    dispatch(
      getExistingFiles({
        [fieldId]: {
          newFiles,
          existingFiles: res.data.filter((file: any) => destination === file.sharingStatus),
        },
      }),
    );
  } catch (res) {
    console.log(res);
  }
};

export const downloadSpecificationFileEffect = () => async (dispatch: any, getState: any) => {
  const state = getState();
  const prId = state.purchaseRequests.activePR.prId;
  const language = state.intl.locale;
  const title = state.intl.messages.purchase.titles.prSpecificationSection.replace(' ', '-');
  try {
    const specificationType = 'docx';
    const specificationURL = `purchases/${prId}/spec/generate/${specificationType}?ln=${language}`;
    const specificationDocumentName = `${prId}_${title}_${language}.${specificationType}`;
    dispatch(downloadSingleFileEffect(specificationURL, specificationDocumentName));
  } catch (res) {
    console.log(res);
  }
};

export const downloadSingleFileEffect = (fileURL: string, fileName: string) => async (dispatch: any, getState: any) => {
  const state = getState();
  try {
    const fileAsBlobRes: any = await requester.get(fileURL, { responseType: 'blob' });
    fileDownload(fileAsBlobRes.data, fileName);
  } catch (res) {
    console.log(res);
  }
};

export const createFileInEDM = (
  destination: string,
  sharingStatus: string,
  personalData: string,
  documentType: string,
) => async (dispatch: any, getState: any) => {
  const state = getState();
  if (
    state.droppedFiles &&
    state.droppedFiles[destination] &&
    state.droppedFiles[destination].newFiles &&
    state.droppedFiles[destination].newFiles.length > 0 &&
    state.purchaseRequests &&
    state.purchaseRequests.activePR &&
    state.purchaseRequests.activePR &&
    state.purchaseRequests.activePR.prId
  ) {
    const filesArray = state.droppedFiles[destination].newFiles;
    const prId = state.purchaseRequests.activePR.prId;
    await Promise.all(
      filesArray.map(async (fileParam: any) => {
        const file = {
          name: fileParam.name,
          purchaseRequestId: prId,
          sharingStatus,
          personalData,
          file: fileParam,
          documentType,
        };
        try {
          await dispatch(createOneFileInEDM(file, destination));
          await dispatch(deleteOneFileByIndexEffect(destination, fileParam.index));
          dispatch(
            addOneNotificationEffectWrapper({
              message: [
                `saveFileInGed_${destination}_success1`,
                `${file.name}`,
                `saveFileInGed_${destination}_success2`,
              ],
              type: 'success',
            }),
          );
        } catch (err) {
          console.log(err);
          await dispatch(deleteOneFileByIndexEffect(destination, fileParam.index));
          dispatch(
            addOneNotificationEffectWrapper({
              message: [`saveFileInGed_${destination}_error`, `${file.name}`],
              type: 'error',
            }),
          );
        }
      }),
    );
    // await dispatch(resetNewFilesEffect(destination));
  }
  // await dispatch(updatePREffect(res.data));
  // dispatch(push(`/purchase/${res.data.purchaseRequest.prId}`));
};

export const createOneFileInEDM = (
  file: {
    name: string;
    purchaseRequestId: string;
    sharingStatus: string;
    personalData: string;
    file: any;
    documentType: string;
  },
  destination: string,
) => async (dispatch: any) => {
  try {
    const fileAsFormData = new FormData();
    fileAsFormData.append('fileName', file.name);
    fileAsFormData.append('purchaseRequestId', file.purchaseRequestId);
    fileAsFormData.append('sharingStatus', file.sharingStatus);
    fileAsFormData.append('personalData', file.personalData);
    fileAsFormData.append('file', file.file);
    fileAsFormData.append('documentType', file.documentType);

    const res: any = await requester.post('ged', fileAsFormData);
    await dispatch(addDroppedFileEffect(destination, [res.data], 'existingFiles'));
  } catch (err) {
    console.log(err);
    throw err;
  }
};

export const deleteFileFromEDM = (
  docId: string,
  purchaseRequestId: string,
  fieldId: string,
  destination: string,
  fileName: string,
) => async (dispatch: any) => {
  try {
    const res: any = await requester.delete(`ged/${docId}/${purchaseRequestId}`);
    dispatch(
      addOneNotificationEffectWrapper({
        message: [`deleteFileInGed_success1`, `${fileName}`, `saveFileInGed_success2`],
        type: 'success',
      }),
    );
    await dispatch(getExistingFilesEffect(fieldId, destination));
  } catch (err) {
    console.log(err);
    dispatch(
      addOneNotificationEffectWrapper({
        message: [`deleteFileInGed_error`, `${fileName}`],
        type: 'error',
      }),
    );
  }
};
