import { connectRouter, RouterState } from 'connected-react-router';
import { History } from 'history';
import { AnyAction, combineReducers, Reducer } from 'redux';

import authenticationReducer, { AuthenticationState } from '@bsc/redux-authentication';

import purchaseRequestsReducer from './purchaseRequests/purchaseRequests.reducers';
import { PurchaseRequestsState } from './purchaseRequests/purchaseRequests.interfaces';
import tasksReducer from './tasks/tasks.reducer';
import { TasksState } from './tasks/tasks.interfaces';
import suppliersReducer from './suppliers/suppliers.reducer';
import { SuppliersState } from './suppliers/suppliers.interface';
import languageReducer from './language/language.reducers';
import { PrModelsState } from './prModels/prModels.interfaces';
import prModelsReducer from './prModels/prModels.reducer';
import { DroppedFilesState } from './droppedFiles/droppedFiles.interfaces';
import droppedFilesReducer from './droppedFiles/droppedFiles.reducers';
import { NotificationsState } from './notifications/notifications.interfaces';
import notificationsReducer from './notifications/notifications.reducers';

export interface AppState {
  router: RouterState;
  intl: any;
  authentication: AuthenticationState;
  purchaseRequests: PurchaseRequestsState;
  tasks: TasksState;
  prModels: PrModelsState;
  suppliers: SuppliersState;
  droppedFiles: DroppedFilesState;
  notifications: NotificationsState;
}

const rootReducer = (history: History) =>
  combineReducers<AppState>({
    router: connectRouter(history) as Reducer<RouterState, AnyAction>,
    intl: languageReducer,
    authentication: authenticationReducer,
    purchaseRequests: purchaseRequestsReducer,
    tasks: tasksReducer,
    prModels: prModelsReducer,
    suppliers: suppliersReducer,
    droppedFiles: droppedFilesReducer,
    notifications: notificationsReducer,
  });

export default rootReducer;
