import { requester } from '../../helpers/api';
import * as effects from './language.effects';
import translationMessages from '../../intl';
import { actionTypes } from './language.actions';

describe('language.effects', () => {
  let mockState: {
    [key: string]: any;
  };
  beforeEach(() => {
    mockState = {
      authentication: {
        accessToken: 'token',
        user: {},
      },
      intl: {
        backFiltredIntl: {
          en: {
            mifid: 'Market In Financial Instruments Directive (MIFID)',
            NA: 'Not applicable',
            EXPOSED: 'Exposed',
            INIT: 'Initial',
            BOTH: 'Exposed and Initiated',
          },
          fr: {
            mifid: 'Charte de déontologie (MIFID)',
            NA: 'Non applicable',
            EXPOSED: 'Exposé',
            INIT: 'Initial',
            BOTH: 'Exposé et initié',
          },
        },
      },
    };
  });

  describe('selectLang effect', () => {
    it('should select en language', () => {
      const dispatch = jest.fn();
      const getState = jest.fn(() => mockState);
      const backFiltredIntl = getState().intl.backFiltredIntl;
      effects.selectLang('en')(dispatch, getState);
      expect(dispatch).toBeCalledTimes(1);
      expect(dispatch).toHaveBeenNthCalledWith(1, {
        payload: {
          locale: 'en',
          messages: translationMessages['en'],
          messagesFromBack: backFiltredIntl['en'],
        },
        type: actionTypes.LANGUAGE.SELECT,
      });
      expect(getState).toBeCalledTimes(2);
    });

    it('should select fr language', () => {
      const dispatch = jest.fn();
      const getState = jest.fn(() => mockState);
      const backFiltredIntl = getState().intl.backFiltredIntl;
      effects.selectLang('fr')(dispatch, getState);
      expect(dispatch).toBeCalledTimes(1);
      expect(dispatch).toHaveBeenNthCalledWith(1, {
        payload: {
          locale: 'fr',
          messages: translationMessages['fr'],
          messagesFromBack: backFiltredIntl['fr'],
        },
        type: actionTypes.LANGUAGE.SELECT,
      });
      expect(getState).toBeCalledTimes(2);
    });
  });

  describe('getIntlFromBack effect', () => {
    let getSuccessMockData: {};

    beforeEach(() => {
      getSuccessMockData = [
        {
          code: 'segmentTypeCode',
          label: 'Precision on the type of segment',
          lang: 'EN',
          choices: [
            {
              code: 'LEVEL_1_EMBARGO_ALERT',
              label: 'Service monitoring level 1 embargo alert',
            },
            {
              code: 'LEVEL_2_EMBARGO_ALERT',
              label: 'Service monitoring level 2 embargo alert',
            },
            {
              code: 'BACK_OFFICE_OPERATIONS',
              label: 'Back-office operations for OPER, GTPS, PSC services',
            },
          ],
        },
      ];
    });

    it('should get labels from WS and ', async () => {
      requester.get = jest.fn(() => Promise.resolve({ data: getSuccessMockData }));

      const dispatch = jest.fn();
      const getState = jest.fn(() => mockState);
      await effects.getIntlFromBack()(dispatch, getState);
      expect(getState).toBeCalledTimes(1);
      expect(dispatch).toBeCalledTimes(2);
    });
  });
});
