import reducer from './index';
import { intlReducer } from 'react-intl-redux';
import { LanguageState } from './language.interfaces';
import { actionTypes } from './language.actions';
import translationMessages, { userLocale } from '../../intl';

describe('language.reducer', () => {
  const allowedLocales = ['en', 'fr'];
  const defaultLocale = 'en';
  const initialLocale: string = allowedLocales.includes(userLocale) ? userLocale : defaultLocale;

  let initialState: LanguageState;
  let payload: any;
  let messagesFromBack: any;
  beforeEach(() => {
    initialState = {
      locale: initialLocale,
      messages: translationMessages[initialLocale],
      messagesFromBack: {},
      backFiltredIntl: {},
    };
  });
  afterEach(() => {
    payload = undefined;
  });

  it('should return initial state when get an undefined action', () => {
    expect(
      reducer(undefined, {
        type: undefined,
        payload: undefined,
      }),
    ).toEqual(initialState);
  });

  it('should return the state with locale and messages', () => {
    payload = {
      locale: 'en',
      messages: {
        userOrigin: 'somewhere',
        uid: 'This is an ID',
        email: 'jon.doe@socgen.com',
        firstName: 'Jon',
        lastName: 'Doe',
      },
    };
    expect(
      reducer(initialState, {
        type: actionTypes.LANGUAGE.SELECT,
        payload,
      }),
    ).toEqual({
      ...initialState,
      ...payload,
    });
  });

  it('should return the state with back locale and messages', () => {
    payload = {
      messagesFromBack: {
        Amount: 'Montant',
        BOTH: 'Exposé et initié',
        BUS: 'Critères métiers',
        BUSINESS: 'Conseil en Management et/ou Organisation',
        CAPACITE:
          'Capacité du fournisseur à prendre en charge les divers composants de lenvironnement et à garantir le résultat et laboutissement de la mission',
        COMPLIANCE: 'Réglementaire / Risques',
        COST: 'Réduction de coût / Efficacité',
        DATA_TYPE: 'Types de Données à caractère personnel traitées',
      },
    };
    expect(
      reducer(initialState, {
        type: actionTypes.LANGUAGE.SET_INTL,
        payload,
      }),
    ).toEqual({
      ...initialState,
      ...payload,
    });
  });

  it('should add a message to messagesFromBack', () => {
    const payload = { code: 'code', label: 'label' };
    expect(
      reducer(initialState, {
        type: actionTypes.LANGUAGE.ADD_TEMPORARY_INTL,
        payload,
      }),
    ).toEqual({
      ...initialState,
      ...{ messagesFromBack: { code: 'label' } },
    });
  });
});
