import { intlReducer } from 'react-intl-redux';
import { Reducer } from 'redux';
import { actionTypes } from './language.actions';
import { LanguageAction, LanguageState } from './language.interfaces';
import translationMessages, { userLocale } from '../../intl';

const allowedLocales = ['en', 'fr'];
const defaultLocale = 'en';
/* istanbul ignore next */
const initialLocale: string = allowedLocales.includes(userLocale) ? userLocale : defaultLocale;

const initialState = {
  locale: initialLocale,
  messages: translationMessages[initialLocale],
  messagesFromBack: {},
  backFiltredIntl: {},
};

const reducer: Reducer<LanguageState, LanguageAction> = (state = initialState, action) => {
  switch (action.type) {
    case actionTypes.LANGUAGE.SELECT:
      return {
        ...state,
        ...action.payload,
      };
    case actionTypes.LANGUAGE.SET_INTL:
      return {
        ...state,
        ...action.payload,
      };
    case actionTypes.LANGUAGE.ADD_TEMPORARY_INTL:
      let newMessagesFromBack = { messagesFromBack: state.messagesFromBack };
      const { code, label } = action.payload;
      newMessagesFromBack.messagesFromBack[code] = label;
      return {
        ...state,
        ...newMessagesFromBack,
      };
    default:
      return intlReducer(state, action);
  }
};
export default reducer;
