import * as effects from './notifications.effects';
import { actionTypes } from './notifications.actions';

describe('notifications.effects', () => {
  describe('addOneNotificationEffect effect', () => {
    it('should create an object to store for each uploaded file from model - two keys', () => {
      const payload = {
        message: ['Success msg'],
        type: 'warning',
      };
      const dispatch = jest.fn();
      const getState = jest.fn(() => ({
        notifications: {
          notifications: [
            {
              key: '1',
              message: 'error abc',
              type: 'error',
            },
            {
              key: '2',
              message: 'info msg',
              type: 'info',
            },
          ],
        },
      }));
      const expectedPayload = {
        notifications: [
          {
            key: '1',
            message: 'error abc',
            type: 'error',
          },
          {
            key: '2',
            message: 'info msg',
            type: 'info',
          },
          {
            key: 12,
            ...payload,
          },
        ],
      };

      effects.addOneNotificationEffect(payload, 12)(dispatch, getState);
      expect(dispatch).toBeCalledTimes(1);
      expect(dispatch).toHaveBeenNthCalledWith(1, {
        payload: expectedPayload,
        type: actionTypes.NOTIFICATION_ADD_ONE,
      });
    });
  });

  describe('addOneNotificationEffectWrapper effect', () => {
    it('should dispatch addOneNotificationEffect effect', () => {
      const payload = {
        message: ['Success msg'],
        type: 'success',
      };
      const dispatch = jest.fn();

      effects.addOneNotificationEffectWrapper(payload)(dispatch);
      expect(dispatch).toBeCalledTimes(1);
    });
  });

  describe('deleteOneNotificationEffect effect', () => {
    it('should delete one notificaiton by key', () => {
      const dispatch = jest.fn();
      const getState = jest.fn(() => ({
        notifications: {
          notifications: [
            {
              key: 1,
              message: 'error abc',
              type: 'error',
            },
            {
              key: 2,
              message: 'info msg',
              type: 'info',
            },
            {
              key: 3,
              message: 'success msg',
              type: 'success',
            },
          ],
        },
      }));

      const expectedPayload = {
        notifications: [
          {
            key: 1,
            message: 'error abc',
            type: 'error',
          },
          {
            key: 3,
            message: 'success msg',
            type: 'success',
          },
        ],
      };

      effects.deleteOneNotificationEffect(2)(dispatch, getState);
      expect(dispatch).toBeCalledTimes(1);
      expect(dispatch).toHaveBeenNthCalledWith(1, {
        payload: expectedPayload,
        type: actionTypes.NOTIFICATION_DELETE_ONE,
      });
    });
  });
});
