import * as effects from './purchaseRequests.effects';
import { actionTypes } from './purchaseRequests.actions';
import { requester } from '../../helpers/api';

describe('purchaseRequests.effects', () => {
  describe('setPRsEffect effect', () => {
    it('should set purchase request array as userPRs key value list', () => {
      const payload = ['PR1', 'PR2'];
      const dispatch = jest.fn();

      effects.setPRsEffect(payload)(dispatch);
      expect(dispatch).toBeCalledTimes(1);
      expect(dispatch).toHaveBeenNthCalledWith(1, {
        payload: { userPRs: payload },
        type: actionTypes.PURCHASEREQUESTS.SET_ALL,
      });
    });
  });

  describe('setPREffect effect', () => {
    it('should set the active PR', () => {
      const payload = { test: 'this is a PR!' };
      const dispatch = jest.fn();

      effects.setPREffect(payload)(dispatch);
      expect(dispatch).toBeCalledTimes(1);
      expect(dispatch).toHaveBeenNthCalledWith(1, {
        payload: { activePR: payload },
        type: actionTypes.PURCHASEREQUESTS.SET,
      });
    });
  });

  describe('syncSuppliersFromPRInputStoreEffect effect', () => {
    it('should trigger getSelectedSuppliersListEffect effect', () => {
      const dispatch = jest.fn();
      const getState = jest.fn(() => ({
        purchaseRequests: {
          activePR: {
            suppliersIds: ['id3, id4'],
          },
        },
      }));

      effects.syncSuppliersFromPRInputStoreEffect()(dispatch, getState);
      expect(dispatch).toBeCalledTimes(1);
    });
  });

  describe('resetPREffect effect', () => {
    it('should set purchase request array as userPRs key value list', () => {
      const dispatch = jest.fn();

      effects.resetPREffect()(dispatch);
      expect(dispatch).toBeCalledTimes(1);
      expect(dispatch).toHaveBeenNthCalledWith(1, {
        payload: { activePR: null },
        type: actionTypes.PURCHASEREQUESTS.RESET,
      });
    });
  });

  describe('pushToValidationEffect effect', () => {
    it('should set purchase request array as userPRs key value list', async () => {
      const getSuccessMockData = [
        {
          assignee: '9c13263d-7b2b-4d60-a7e3-8443b380d396',
          candidateGroups: ['REQUESTOR_GROUP'],
          candidateUsers: ['9c13263d-7b2b-4d60-a7e3-8443b380d396'],
          id: 'c48feb86-70ad-11e9-9dcb-0242ac120013',
          name: 'UserTask_CreatePurchaseRequest',
          variables: null,
        },
      ];

      const prModelsMock = {
        prModels: {
          inputsModel: {
            amount: {
              type: 'inputTextOrTextarea',
              hasManagementRule: true,
              value: 20000000,
              config: {},
              muiPropsCustomConf: {},
            },
            assignmentTriggerCode: {
              type: 'selectfield',
              value: 'COMPLIANCE',
              config: {},
              muiPropsCustomConf: {},
              touched: true,
            },
          },
        },
      };

      const requestPOSTBody = { amount: 20000000, assignmentTriggerCode: 'COMPLIANCE' };

      const dispatch = jest.fn();
      const getState = jest.fn(() => ({
        purchaseRequests: {
          activePR: {
            prId: 'PR000006548',
          },
        },
        prModels: prModelsMock.prModels,
      }));
      requester.get = jest.fn(() =>
        Promise.resolve({
          status: 200,
          data: getSuccessMockData,
        }),
      );
      requester.post = jest.fn(() =>
        Promise.resolve({
          status: 200,
          data: prModelsMock.prModels.inputsModel,
        }),
      );
      await effects.pushToValidationEffect()(dispatch, getState);
      expect(requester.get).toBeCalledTimes(1);
      expect(requester.post).toBeCalledTimes(1);
      expect(dispatch).toBeCalledTimes(1);
      expect(requester.get).toHaveBeenNthCalledWith(1, 'purchases/PR000006548/tasks');
      expect(requester.post).toHaveBeenNthCalledWith(
        1,
        'purchases/PR000006548/tasks/c48feb86-70ad-11e9-9dcb-0242ac120013/validate',
        requestPOSTBody,
      );
    });
  });

  describe('updatePR effect', () => {
    it('should update the PR and the inputs', async () => {
      const dispatch = jest.fn();
      const getState = jest.fn(() => ({
        prModels: {
          inputsModels: null,
        },
      }));
      effects.updatePREffect({})(dispatch, getState);
    });
  });

  describe('resetPurchaseEffect effect', () => {
    it('should reset the PR, Task and InputsModel', () => {
      const dispatch = jest.fn();
      const getState = jest.fn(() => ({
        tasks: {
          activeTask: true,
        },
        purchaseRequests: {
          activePR: true,
        },
        prModels: {
          inputsModel: true,
        },
      }));
      effects.resetPurchaseEffect()(dispatch, getState);
      expect(dispatch).toBeCalledTimes(3);
    });
  });
});
