import { push } from 'connected-react-router';

import { requester } from '../../helpers/api';
import { mockedCreatePR, mockedFetchAllRequest } from '../../template/mock-data';
import { editInputsModelEffect, getInputsModelEffect, getPrValues, resetInputsModelEffect } from '../prModels';
import { resetPR, setPR, setPRs, updatePR } from '../purchaseRequests/purchaseRequests.actions';
import { resetTaskEffect } from '../tasks';
import { getSelectedSuppliersListEffect } from '../suppliers';
import { createFileInEDM, getExistingFilesEffect } from '../droppedFiles';
import { addOneNotificationEffectWrapper } from '../notifications';

// Set the user PRs in the store
export const setPRsEffect = (payload: any[]) => (dispatch: any) => {
  dispatch(setPRs({ userPRs: payload }));
};

// Set the active PR in the store
export const setPREffect = (payload: any) => (dispatch: any) => {
  dispatch(setPR({ activePR: payload }));
};

// Reset the PR
export const resetPREffect = () => (dispatch: any) => {
  dispatch(resetPR({ activePR: null }));
};

// Get the model then update it with the values of the active PR
export const updatePREffect = (activePR: any) => async (dispatch: any, getState: any) => {
  // we set the active PR
  await dispatch(updatePR({ activePR: activePR }));
  // If the inputsModel is null we fetch it
  if (!getState().prModels.inputsModel) {
    await dispatch(getInputsModelEffect());
  }
  // We edits the models with the values from the new active PR
  await dispatch(editInputsModelEffect());
};

// Fetch all the requests in the server and set them in the store
export const fetchAllRequestEffect = () => async (dispatch: any, getState: any) => {
  const state = getState();

  const defaultPageNumber = 1; // Add to store
  const defaultpageSize = 100; // Add to store

  try {
    const res: any = await requester.get(`purchases?pageNumber=${defaultPageNumber}&pageSize=${defaultpageSize}`);
    dispatch(setPRsEffect(res.data.elements));
  } catch (resp) {
    dispatch(setPRsEffect(mockedFetchAllRequest));
  }
};

export const syncSuppliersFromPRInputStoreEffect = () => (dispatch: any, getState: any) => {
  const state = getState();
  const selectedSuppliersIds = state.purchaseRequests.activePR.suppliersIds;
  dispatch(getSelectedSuppliersListEffect(selectedSuppliersIds));
};

// Find a PR with the PR id, it will set the result in the store
export const findPREffect = (prId: string) => async (dispatch: any) => {
  try {
    const res: any = await requester.get(`purchases/${prId}`);
    await dispatch(setPREffect(res.data));
    dispatch(syncSuppliersFromPRInputStoreEffect());
  } catch (res) {
    console.log(res);
    await dispatch(setPREffect(mockedCreatePR));
  }
};

// Effect when creating a new PR
export const createPREffect = () => async (dispatch: any, getState: any) => {
  try {
    const res: any = await requester.post('purchases', {}, { headers: { 'X-language': getState().intl.locale } });
    await dispatch(updatePREffect(res.data));
    dispatch(push(`/purchase/${res.data.prId}#prDescriptionSection`));
  } catch (err) {
    console.log(err);
    await dispatch(updatePREffect(mockedCreatePR));
    dispatch(push(`/purchase/${mockedCreatePR.prId}#prDescriptionSection`));
  }
};

// Effect to save a PR
export const savePREffect = () => async (dispatch: any, getState: any) => {
  const state = getState();
  const prId = state.purchaseRequests.activePR.prId;
  const updatedValue = getPrValues(state.prModels.inputsModel);
  try {
    const res: any = await requester.put(`purchases/${prId}`, { ...updatedValue });
    // We edit the PR with the server answear to always be up to date
    await dispatch(updatePREffect(res.data));
    await dispatch(createFileInEDM('prFilesExternal', 'external_document', 'true', 'attachment'));
    await dispatch(createFileInEDM('prFilesInternal', 'internal_document', 'true', 'attachment'));
    await dispatch(getExistingFilesEffect('prFilesExternal', 'external_document'));
    await dispatch(getExistingFilesEffect('prFilesInternal', 'internal_document'));
    dispatch(
      addOneNotificationEffectWrapper({ message: ['savePR_success1', `${prId}`, 'savePR_success2'], type: 'success' }),
    );
  } catch (res) {
    console.log(res);
    dispatch(addOneNotificationEffectWrapper({ message: ['savePR_error', `${prId}`], type: 'error' }));
  }
};

// Effect to push to validation a PR
export const pushToValidationEffect = () => async (dispatch: any, getState: any) => {
  const state = getState();
  const prId = state.purchaseRequests.activePR.prId;

  const updatedValue = getPrValues(state.prModels.inputsModel);

  try {
    const res: any = await requester.get(`purchases/${prId}/tasks`);
    const tasks = res.data;
    const taskId = tasks.filter((task: any) => task.name === 'UserTask_CreatePurchaseRequest')[0].id;
    await requester.post(`purchases/${prId}/tasks/${taskId}/validate`, updatedValue);
    dispatch(push(`/purchase/${prId}/summary?panel=publication`));
  } catch (res) {
    console.log(res);
  }
};

export const resetPurchaseEffect = () => (dispatch: any, getState: any) => {
  const state = getState();
  const activeTask = state.tasks.activeTask;
  const activePR = state.purchaseRequests.activePR;
  const inputsModel = state.prModels.inputsModel;
  activeTask !== null && dispatch(resetTaskEffect());
  activePR !== null && dispatch(resetPREffect());
  inputsModel !== null && dispatch(resetInputsModelEffect());
};
