import reducer from './index';
import { PurchaseRequestsState } from './purchaseRequests.interfaces';
import { actionTypes } from './purchaseRequests.actions';

describe('purchaseRequests.reducer', () => {
  let initialState: PurchaseRequestsState;
  let payload: any;
  beforeEach(() => {
    initialState = {
      activePR: null,
      userPRs: [],
    };
  });
  afterEach(() => {
    payload = undefined;
  });

  describe('DEFAULT case', () => {
    it('should return initial state when get an undefined action', () => {
      expect(
        reducer(undefined, {
          type: undefined,
          payload: undefined,
        }),
      ).toEqual(initialState);
    });
  });

  describe('PURCHASEREQUESTS.SET_ALL case', () => {
    it('should return the state with updated userPRs', () => {
      payload = {
        activePR: null,
        userPRs: ['PR1', 'PR2'],
      };
      expect(
        reducer(initialState, {
          type: actionTypes.PURCHASEREQUESTS.SET_ALL,
          payload,
        }),
      ).toEqual({
        ...initialState,
        ...payload,
      });
    });
  });

  describe('PURCHASEREQUESTS.SET case', () => {
    it('should return the state with updated userPRs', () => {
      payload = {
        activePR: { pr: 'this is a purchase request!' },
        userPRs: null,
      };
      expect(
        reducer(initialState, {
          type: actionTypes.PURCHASEREQUESTS.SET,
          payload,
        }),
      ).toEqual({
        ...initialState,
        ...payload,
      });
    });
  });

  describe('PURCHASEREQUESTS.RESET case', () => {
    it('should return the state keeping userPRs and resetting other keys', () => {
      payload = { activePR: null };
      expect(
        reducer(initialState, {
          type: actionTypes.PURCHASEREQUESTS.RESET,
          payload,
        }),
      ).toEqual({
        ...initialState,
        ...payload,
      });
    });
  });

  describe('PURCHASEREQUESTS.UPDATE case', () => {
    it('should return the state keeping userPRs and updating other keys', () => {
      payload = { activePR: { purchaseRequest: {} } };
      expect(
        reducer(initialState, {
          type: actionTypes.PURCHASEREQUESTS.UPDATE,
          payload,
        }),
      ).toEqual({
        ...initialState,
        ...payload,
      });
    });
  });
});
