import { routerMiddleware } from 'connected-react-router';
import { createBrowserHistory } from 'history';
import { applyMiddleware, createStore } from 'redux';
import { composeWithDevTools } from 'redux-devtools-extension/logOnlyInProduction';
import thunk from 'redux-thunk';
import { REACT_APP_BASE_NAME } from '../config/env-var';

import rootReducer from './index';

const history = createBrowserHistory({
  basename: REACT_APP_BASE_NAME,
});

function configureStore() {
  // configure middlewares
  const middlewares = [thunk, routerMiddleware(history)];
  if (process.env.NODE_ENV === 'development') {
    const logger = require('redux-logger').createLogger({
      collapsed: true,
    });
    middlewares.push(logger);
  }

  // compose enhancers
  const enhancer = composeWithDevTools({})(applyMiddleware(...middlewares));
  // create store
  return createStore(rootReducer(history), {}, enhancer);
}

const store = configureStore();

// export store singleton instance
export { store, history };
