import { setSuppliers, changePageOfSuppliersList, selectSupplier, unselectSupplier } from '../suppliers';
import { updatePR } from '../purchaseRequests/purchaseRequests.actions';
import { updateInputEffect } from '../prModels';
import { requester } from '../../helpers/api';

export const setSuppliersEffect = (suppliersList: any, numberOfPages: number) => (dispatch: any) => {
  const suppliers = { allSuppliers: suppliersList, numberOfPages };
  dispatch(setSuppliers(suppliers));
};

export const syncSuppliersInPRInputStoreEffect = () => (dispatch: any, getState: any) => {
  const state = getState();
  const selectedSuppliersIds = state.suppliers.selectedSuppliersIds;
  dispatch(updateInputEffect(selectedSuppliersIds, 'suppliersIds'));
};

export const selectSupplierEffect = (payload: any) => async (dispatch: any) => {
  await dispatch(selectSupplier(payload));
  dispatch(syncSuppliersInPRInputStoreEffect());
};

export const getOneSupplierByIdEffect = (supplierId: string) => async (dispatch: any) => {
  try {
    const res: any = await requester.get(`suppliers/${supplierId}`);
    await dispatch(selectSupplierEffect(res.data));
  } catch (res) {
    console.log(res);
  }
};

export const getSelectedSuppliersListEffect = (supplierListIds: any[]) => async (dispatch: any) =>
  await supplierListIds.forEach(async supplierId => await dispatch(getOneSupplierByIdEffect(supplierId)));

export const unselectSupplierEffect = (payload: any) => async (dispatch: any) => {
  await dispatch(unselectSupplier(payload));
  dispatch(syncSuppliersInPRInputStoreEffect());
};

export const changePageOfSuppliersEffect = (paging: any) => (dispatch: any) => {
  dispatch(changePageOfSuppliersList(paging));
  dispatch(searchForSuppliersEffect(paging));
};

export const searchForSuppliersEffect = (paging?: any) => async (dispatch: any, getState: any) => {
  const state = getState();
  const newPaging = {
    currentPage: paging ? paging.currentPage : 1,
    resultsPerPage: state.suppliers.paging.resultsPerPage,
  };

  const onlyReferencedSuppliers = state.suppliers.isFiltredSuppliers;
  const searchTerm = state.suppliers.searchTerm;

  try {
    const res: any = await requester.get(
      `suppliers?pageNumber=${newPaging.currentPage}&pageSize=${
        newPaging.resultsPerPage
      }&name=${searchTerm}&showApprovedOnly=${onlyReferencedSuppliers}`,
    );
    const suppliers = res.data.elements;
    const numberOfPages = res.data.numberOfPages;
    dispatch(changePageOfSuppliersList(newPaging));
    dispatch(setSuppliersEffect(suppliers, numberOfPages));
  } catch (res) {
    console.log(res);
  }
};
