import reducer from './';
import { SuppliersState } from './suppliers.interface';
import { actionTypes } from './suppliers.actions';

describe('purchaseRequests.reducer', () => {
  let initialState: SuppliersState;
  let payload: any;
  beforeEach(() => {
    initialState = {
      allSuppliers: [],
      searchTerm: '',
      isFiltredSuppliers: true,
      selectedSuppliers: [],
      selectedSuppliersIds: [],
      paging: {
        currentPage: 1,
        resultsPerPage: 16,
      },
      numberOfPages: 0,
    };
  });
  afterEach(() => {
    payload = undefined;
  });

  describe('DEFAULT case', () => {
    it('should return initial state when get an undefined action', () => {
      expect(
        reducer(undefined, {
          type: undefined,
          payload: undefined,
        }),
      ).toEqual(initialState);
    });
  });

  describe('SUPPLIERS.SET_ALL case', () => {
    it('should return the state with updated allSuppliers', () => {
      payload = {
        allSuppliers: [
          {
            id: '152',
            name: 'CAPGEMINI',
            supplierRiskLevel: 'low',
            isSupplierReferenced: false,
          },
          {
            id: '153',
            name: 'SOPRA',
            supplierRiskLevel: 'medium_low',
            isSupplierReferenced: true,
          },
        ],
      };

      const expectedState = {
        allSuppliers: [
          {
            id: '152',
            name: 'CAPGEMINI',
            supplierRiskLevel: 'low',
            isSupplierReferenced: false,
          },
          {
            id: '153',
            name: 'SOPRA',
            supplierRiskLevel: 'medium_low',
            isSupplierReferenced: true,
          },
        ],
        selectedSuppliers: [],
        selectedSuppliersIds: [],
        paging: {
          currentPage: 1,
          resultsPerPage: 16,
        },
        numberOfPages: 0,
        searchTerm: '',
        isFiltredSuppliers: true,
      };

      expect(
        reducer(initialState, {
          type: actionTypes.SUPPLIERS.SET_ALL,
          payload,
        }),
      ).toEqual(expectedState);
    });
  });

  describe('SUPPLIERS.SELECT case', () => {
    it('should return the state with updated selectedSuppliers: select case', () => {
      payload = {
        id: '152',
        name: 'CAPGEMINI',
        supplierRiskLevel: 'low',
        isSupplierReferenced: false,
      };

      const expectedState = {
        allSuppliers: [],
        selectedSuppliers: [
          {
            id: '152',
            name: 'CAPGEMINI',
            supplierRiskLevel: 'low',
            isSupplierReferenced: false,
          },
        ],
        selectedSuppliersIds: ['152'],
        paging: {
          currentPage: 1,
          resultsPerPage: 16,
        },
        numberOfPages: 0,
        searchTerm: '',
        isFiltredSuppliers: true,
      };

      expect(
        reducer(initialState, {
          type: actionTypes.SUPPLIERS.SELECT,
          payload,
        }),
      ).toEqual(expectedState);
    });
  });

  describe('SUPPLIERS.UNSELECT case', () => {
    it('should return the state with updated selectedSuppliers: unselect case', () => {
      const customInitialState = {
        allSuppliers: [],
        selectedSuppliers: [
          {
            id: '152',
            name: 'CAPGEMINI',
            supplierRiskLevel: 'low',
            isSupplierReferenced: false,
          },
        ],
        selectedSuppliersIds: ['152'],
        paging: {
          currentPage: 1,
          resultsPerPage: 16,
        },
        numberOfPages: 0,
        searchTerm: '',
        isFiltredSuppliers: true,
      };

      payload = {
        id: '152',
        name: 'CAPGEMINI',
        supplierRiskLevel: 'low',
        isSupplierReferenced: false,
      };

      const expectedState = {
        allSuppliers: [],
        selectedSuppliers: [],
        selectedSuppliersIds: [],
        paging: {
          currentPage: 1,
          resultsPerPage: 16,
        },
        numberOfPages: 0,
        searchTerm: '',
        isFiltredSuppliers: true,
      };

      expect(
        reducer(customInitialState, {
          type: actionTypes.SUPPLIERS.UNSELECT,
          payload,
        }),
      ).toEqual(expectedState);
    });
  });

  describe('SUPPLIERS.SEARCH SUPPLIERS.FILTER_BY_REFERENCE SUPPLIERS.CHANGE_PAGE case', () => {
    it('should return the state with new searchTerm', () => {
      payload = 'test';

      const expectedState = {
        allSuppliers: [],
        selectedSuppliers: [],
        selectedSuppliersIds: [],
        paging: {
          currentPage: 1,
          resultsPerPage: 16,
        },
        numberOfPages: 0,
        searchTerm: 'test',
        isFiltredSuppliers: true,
      };

      expect(
        reducer(initialState, {
          type: actionTypes.SUPPLIERS.SEARCH,
          payload,
        }),
      ).toEqual(expectedState);
    });
    it('should return the state with new paging', () => {
      payload = {
        currentPage: 2,
        resultsPerPage: 16,
      };

      const expectedState = {
        allSuppliers: [],
        selectedSuppliers: [],
        selectedSuppliersIds: [],
        paging: {
          currentPage: 2,
          resultsPerPage: 16,
        },
        numberOfPages: 0,
        searchTerm: '',
        isFiltredSuppliers: true,
      };

      expect(
        reducer(initialState, {
          type: actionTypes.SUPPLIERS.CHANGE_PAGE,
          payload,
        }),
      ).toEqual(expectedState);
    });
    it('should return the state with new filterByReference case', () => {
      payload = false;

      const expectedState = {
        allSuppliers: [],
        selectedSuppliers: [],
        selectedSuppliersIds: [],
        paging: {
          currentPage: 1,
          resultsPerPage: 16,
        },
        numberOfPages: 0,
        searchTerm: '',
        isFiltredSuppliers: false,
      };

      expect(
        reducer(initialState, {
          type: actionTypes.SUPPLIERS.FILTER_BY_REFERENCE,
          payload,
        }),
      ).toEqual(expectedState);
    });
  });
});
