import { Reducer } from 'redux';
import { actionTypes } from './suppliers.actions';
import { SuppliersAction, SuppliersState } from './suppliers.interface';

const initialState = {
  numberOfPages: 0,
  allSuppliers: [],
  selectedSuppliers: [],
  selectedSuppliersIds: [],
  paging: {
    currentPage: 1,
    resultsPerPage: 16,
  },
  searchTerm: '',
  isFiltredSuppliers: true,
};

const reducer: Reducer<SuppliersState, SuppliersAction> = (state = initialState, action) => {
  switch (action.type) {
    case actionTypes.SUPPLIERS.SET_ALL:
      return {
        ...state,
        ...action.payload,
      };
    case actionTypes.SUPPLIERS.SELECT:
      const alreadySelectedSuppliers = {
        selectedSuppliers: state.selectedSuppliers,
        selectedSuppliersIds: state.selectedSuppliersIds,
      };
      alreadySelectedSuppliers.selectedSuppliers.push(action.payload);
      alreadySelectedSuppliers.selectedSuppliersIds.push(action.payload.id);
      const newSelectedSuppliersAfterSelect = {
        selectedSuppliers: alreadySelectedSuppliers.selectedSuppliers.filter(n => n),
        selectedSuppliersIds: alreadySelectedSuppliers.selectedSuppliersIds,
      };
      return {
        ...state,
        ...newSelectedSuppliersAfterSelect,
      };
    case actionTypes.SUPPLIERS.UNSELECT:
      const selectedSuppliersAfterRemovingUnwantedSupplier = state.selectedSuppliers.filter(
        supplier => supplier.name !== action.payload.name,
      );
      const selectedSuppliersWithoutNullElements = selectedSuppliersAfterRemovingUnwantedSupplier.filter(n => n);
      const newSelectedSuppliersAfterUnselect = {
        selectedSuppliers: selectedSuppliersWithoutNullElements,
        selectedSuppliersIds: selectedSuppliersWithoutNullElements.map(supplier => supplier.id),
      };
      return {
        ...state,
        ...newSelectedSuppliersAfterUnselect,
      };
    case actionTypes.SUPPLIERS.CHANGE_PAGE:
      const newPaging = {
        paging: {
          currentPage: action.payload.currentPage,
          resultsPerPage: action.payload.resultsPerPage,
        },
      };
      return {
        ...state,
        ...newPaging,
      };
    case actionTypes.SUPPLIERS.SEARCH:
      const newSearchTerm = {
        searchTerm: action.payload,
      };
      return {
        ...state,
        ...newSearchTerm,
      };
    case actionTypes.SUPPLIERS.FILTER_BY_REFERENCE:
      const newFiltredSuppliers = {
        isFiltredSuppliers: action.payload,
      };
      return {
        ...state,
        ...newFiltredSuppliers,
      };
    default:
      return state;
  }
};

export default reducer;
