import { push } from 'connected-react-router';

import { requester } from '../../helpers/api';
import { resetTask, setTask, setTasks } from './tasks.actions';

export const setTasksEffect = (payload: any[]) => (dispatch: any) => {
  const userTasks = payload.filter(task => task.platformRequest !== null && task.purchaseRequest !== null);
  dispatch(setTasks({ userTasks }));
};

export const setTaskEffect = (payload: any) => (dispatch: any) => {
  dispatch(setTask({ activeTask: payload }));
};

export const resetTaskEffect = () => (dispatch: any) => {
  dispatch(resetTask({ activeTask: null }));
};

export const fetchAllTasksEffect = () => async (dispatch: any, getState: any) => {
  const state = getState();

  const defaultPageNumber = 1; // Add to store
  const defaultpageSize = 100; // Add to store

  try {
    const data: any = await requester.get(`tasks?pageNumber=${defaultPageNumber}&pageSize=${defaultpageSize}`);
    dispatch(setTasksEffect(data.data.elements));
  } catch (res) {
    console.log(res);
  }
};

// Effect for the approval task
export const approveTaskEffect = () => async (dispatch: any, getState: any) => {
  const state = getState();
  const activePR = state.purchaseRequests.activePR;
  const backendBusinessKey = activePR.platformRequest.backendBusinessKey;
  // This method is only valid when there is only one task of this type, could need rework
  const taskId = state.tasks.activeTask
    ? state.tasks.activeTask.task.id
    : activePR.tasks.find((task: { id: string; name: string }) => task.name === 'UserTask_PublishProposalRequest').id;
  try {
    await requester.post(`tasks/${taskId}/requests/${backendBusinessKey}/approve`);
    dispatch(push('/'));
  } catch (res) {
    console.log(res);
  }
};

// Effect to publish a request
export const publishTaskEffect = () => async (dispatch: any, getState: any) => {
  const state = getState();
  const activePR = state.purchaseRequests.activePR;
  const inputsModel = state.prModels.inputsModel;
  const bodyInputKeys = [
    'supplierOfferReceptionDateTime',
    'supplierOralStartDate',
    'supplierOralEndDate',
    'estimatedDateSupplierSelection',
    'estimatedContractSignatureDate',
    'projectStartDate',
    'projectEndDate',
  ];
  let bodyData: any = {};
  bodyInputKeys.forEach(key => (bodyData[key] = inputsModel[key].value));
  try {
    const res: any = await requester.get(`purchases/${activePR.prId}/tasks`);
    const tasks = res.data;
    const taskId = tasks.filter((task: any) => task.name === 'UserTask_PublishProposalRequest')[0].id;
    await requester.post(`purchases/${activePR.prId}/tasks/${taskId}/publish`, bodyData);
    dispatch(push('/'));
  } catch (res) {
    console.log(res);
  }
};
