import reducer from './';
import { TasksState } from './tasks.interfaces';
import { actionTypes } from './tasks.actions';

describe('purchaseRequests.reducer', () => {
  let initialState: TasksState;
  let payload: any;
  beforeEach(() => {
    initialState = {
      userTasks: [],
      activeTask: null,
    };
  });
  afterEach(() => {
    payload = undefined;
  });

  describe('DEFAULT case', () => {
    it('should return initial state when get an undefined action', () => {
      expect(
        reducer(undefined, {
          type: undefined,
          payload: undefined,
        }),
      ).toEqual(initialState);
    });
  });

  describe('TASKS.SET case', () => {
    it('should return the state with updated activeTask', () => {
      payload = {
        activeTask: 'This is the new active task!',
      };
      expect(
        reducer(initialState, {
          type: actionTypes.TASKS.SET,
          payload,
        }),
      ).toEqual({
        ...initialState,
        ...payload,
      });
    });
  });

  describe('TASKS.SET_ALL case', () => {
    it('should return the state with updated userTasks', () => {
      payload = {
        userTasks: ['Task1', 'Task2'],
      };
      expect(
        reducer(initialState, {
          type: actionTypes.TASKS.SET_ALL,
          payload,
        }),
      ).toEqual({
        ...initialState,
        ...payload,
      });
    });
  });

  describe('TASKS.RESET case', () => {
    it('should reset the activeTask to null', () => {
      initialState.activeTask = 'This is an active Task, for real!';
      payload = { activeTask: null };
      expect(
        reducer(initialState, {
          type: actionTypes.TASKS.RESET,
          payload,
        }),
      ).toEqual({
        ...initialState,
        ...payload,
      });
    });
  });
});
