import { updateObject, checkValidity } from './shared';

describe('updateObject', () => {
  it('should return a updated object', () => {
    const oldObject = { value: 'test' };
    const updatedObject = updateObject(oldObject, {
      valueBis: 'An other value',
      value: 'A new value',
    });
    expect(updatedObject).toEqual({
      value: 'A new value',
      valueBis: 'An other value',
    });
  });
});

describe('checkValidity', () => {
  it('should return true if there is no rules', () => {
    expect(checkValidity('test', undefined)).toEqual({
      valid: true,
      errorText: null,
    });
  });
  it('should check if string required', () => {
    const validity = checkValidity('Test', { required: true });
    expect(validity).toEqual({
      valid: true,
      errorText: null,
    });
  });
  it('should check if boolean required', () => {
    const validity = checkValidity(false, { required: true });
    expect(validity).toEqual({
      valid: true,
      errorText: null,
    });
  });
  it('should check if number required', () => {
    const validity = checkValidity(15, { required: true });
    expect(validity).toEqual({
      valid: true,
      errorText: null,
    });
  });
  it('should check if null required', () => {
    const validity = checkValidity(null, { required: true });
    expect(validity).toEqual({
      valid: false,
      errorText: 'required',
    });
  });
  it('should check if superior to a number', () => {
    expect(checkValidity(15, { superior: 20 })).toEqual({
      valid: false,
      errorText: 'superiorTo',
    });
    expect(checkValidity(25, { superior: 20 })).toEqual({
      valid: true,
      errorText: null,
    });
  });
  it('should check if the gdpr is valid', () => {
    const validGdpr = [
      {
        orderNumber: 0,
        test: 'test',
        otherValue: 'value',
      },
    ];
    const invalidGdpr = [
      {
        orderNumber: 0,
        test: null,
        otherValue: '',
      },
    ];
    expect(checkValidity(validGdpr, { gdpr: true })).toEqual({
      valid: true,
      errorText: null,
    });
    expect(checkValidity(invalidGdpr, { gdpr: true })).toEqual({
      valid: false,
      errorText: 'gdprError',
    });
  });
});
