export const updateObject = (oldObject: object, updatedProperties: any) => ({
  ...oldObject,
  ...updatedProperties,
});

export const checkValidity = (value: any, rules: any) => {
  let isValid = true;
  let newErrorText = null;
  if (!rules) {
    return { valid: true, errorText: null };
  }

  if (rules.gdpr) {
    let emptyField: boolean = false;
    value.forEach((treatment: any, i: number) => {
      Object.keys(treatment).forEach((key: string) => {
        const gdprValue = value[i][key];
        if ((gdprValue === null || gdprValue === '') && typeof gdprValue !== 'number') {
          emptyField = true;
        }
      });
    });
    isValid = !emptyField;
    if (!isValid) {
      newErrorText = 'gdprError';
    }
  }

  if (rules.required) {
    // const trimValue = !isNaN(value) ? !isNaN(value) : value.trim();
    const valueToCheck =
      typeof value === 'string' ? value.trim() : typeof value === 'boolean' || typeof value === 'number' ? true : false;
    isValid = !!valueToCheck && isValid;
    if (!isValid) {
      newErrorText = 'required';
    }
  }

  if (rules.superior) {
    isValid = value > rules.superior;
    if (!isValid) {
      newErrorText = 'superiorTo';
    }
  }

  if (rules.criteriaSelection) {
    let sum = 0;
    value.forEach((criteria: any) => {
      criteria.criteriaSelectionDetails.forEach((subCriteria: any) => {
        sum += subCriteria.value;
      });
    });

    if (sum < 100 || sum > 100) {
      newErrorText = 'isNotHundredPerCent';
      isValid = false;
    }
  }

  return { valid: isValid, errorText: newErrorText };
};
