import { createMuiTheme } from '@material-ui/core/styles';
import { ThemeOptions } from '@material-ui/core/styles/createMuiTheme';
import deepmerge from 'deepmerge';

import base from './base-theme';
import colors, {
  TEXT_DISABLED_COLOR,
  TEXT_PRIMARY_COLOR,
  TEXT_SECONDARY_COLOR,
  // TEXT_CONTRAST_COLOR
} from './light-colors';

const theme: ThemeOptions = {
  palette: {
    common: { white: '#fff', black: 'rgba(0, 0, 0, 1)' },
    background: { paper: '#fff', default: '#EEEEEE' },
    primary: {
      main: 'rgba(51, 51, 51, 1)',
    },
    secondary: {
      main: 'rgba(230, 0, 40, 1)',
      light: 'rgba(241, 71, 101, 1)',
      dark: 'rgba(195, 0, 34, 1)',
    },
    error: {
      contrastText: '#fff',
      main: 'rgba(241, 113, 0, 1)',
      light: 'rgba(255, 214, 176, 1)',
      dark: 'rgba(185, 41, 45, 1)',
    },
    text: {
      secondary: TEXT_SECONDARY_COLOR,
      disabled: TEXT_DISABLED_COLOR,
      hint: 'rgba(0, 0, 0, 0.38)',
      primary: TEXT_PRIMARY_COLOR,
    },
    colors: {
      ...colors,
    },
  },
  typography: {
    useNextVariants: true,
    code: {
      fontFamily: "'Source Code Pro', monospace",
      fontSize: '13px',
    },
    // font-family: 'Montserrat', sans-serif;
    // font-family: 'Source Sans Pro', sans-serif;
    h1: {
      fontFamily: "'Montserrat', sans-serif",
      fontSize: '40px',
      fontWeight: 100,
      textTransform: 'uppercase',
    },
    h2: {
      fontFamily: "'Source Sans Pro', sans-serif",
      fontSize: '32px',
      fontWeight: 700,
    },
    h3: {
      fontFamily: "'Source Sans Pro', sans-serif",
      fontSize: '28px',
      fontWeight: 700,
    },
    h4: {
      fontFamily: "'Source Sans Pro', sans-serif",
      fontSize: '21px',
      fontWeight: 700,
    },
    subtitle1: {
      fontFamily: "'Source Sans Pro', sans-serif",
      fontSize: '16px',
      fontWeight: 700,
    },
    body1: {
      fontFamily: "'Source Sans Pro', sans-serif",
      fontSize: '16px',
      fontWeight: 400,
    },
    body2: {
      fontFamily: "'Source Sans Pro', sans-serif",
      fontSize: '14px',
      fontWeight: 400,
    },
    caption: {
      fontFamily: "'Source Sans Pro', sans-serif",
      fontSize: '12px',
      fontWeight: 400,
    },
    button: {
      fontFamily: "'Source Sans Pro', sans-serif",
      fontSize: '12px',
      fontWeight: 700,
    },

    // title: {
    //   fontSize: '20px',
    //   fontWeight: 700,
    // },
    // headline: {
    //   fontSize: '24px',
    //   fontWeight: 700,
    // },
    // display1: {
    //   fontSize: '28px',
    //   fontWeight: 300,
    //   color: 'rgba(0,0,0,.85)',
    // },
    // display2: {
    //   fontSize: '37px',
    //   fontWeight: 500,
    //   color: 'rgba(0,0,0,.85)',
    // },
    // display3: {
    //   fontSize: '50px',
    //   fontWeight: 300,
    //   color: 'rgba(0,0,0,.85)',
    // },
  },
  overrides: {
    MuiButton: {
      contained: {
        backgroundColor: '#fff',
      },
    },
    MuiTab: {
      root: {
        textTransform: 'none',
      },
      label: {
        fontSize: '16px!important', // TODO: media query
      },
    },
    MuiTabs: {
      indicator: {
        height: 4,
      },
    },
    MuiAppBar: {
      colorPrimary: {
        backgroundColor: '#FFF',
        color: '#000',
      },
    },
    MuiFormLabel: {
      root: {
        color: 'rgba(0,0,0,.70)',
        '&$focused': {
          color: 'rgba(0,0,0,.85)',
        },
      },
    },
    MuiTableHead: {
      // TODO:
      root: {
        borderTop: '3px solid #ccc',
        '& tr': {
          height: 35,
        },
        '& th': {
          borderBottom: '1px solid #777',
        },
        '& > tr > th:first-child': {
          padding: `0 12px`,
        },
        '& > tr > th:first-child > span': {
          padding: `0 12px`,
        },
      },
    },
    // MuiTypography: {
    //   colorSuccess: {
    //     color: colors.successgreen.main,
    //   },
    //   colorWarning: {
    //     color: colors.warningorange.main,
    //   },
    //   colorDanger: {
    //     color: colors.dangerred.main,
    //   },
    //   colorInfo: {
    //     color: colors.infoblue.main,
    //   },
    //   colorDisclaimer: {
    //     color: colors.darkgrey.main,
    //   },
    // },
  },
};

export default createMuiTheme(deepmerge(base, theme));
